@@ -38,16 +38,14 @@ import (
 )
 
 func TestHelmInstallation(t *testing.T) {
-	KAMEL_INSTALL_REGISTRY := os.Getenv("KAMEL_INSTALL_REGISTRY")
-
 	WithNewTestNamespace(t, func(ctx context.Context, g *WithT, ns string) {
+		containerRegistry, ok := os.LookupEnv("KAMEL_INSTALL_REGISTRY")
+		g.Expect(ok).To(BeTrue())
 		// Let's make sure no CRD is yet available in the cluster
-		// as we must make the Helm procedure to install them accordingly
-		g.Eventually(CRDs(t)).Should(BeNil())
+		// as we must make the procedure to install them accordingly
+		g.Eventually(CRDs(t)).Should(BeNil(), "No Camel K CRDs should be previously installed for this test")
 		operatorID := "helm-ck"
-		g.Expect(KAMEL_INSTALL_REGISTRY).NotTo(Equal(""))
 		os.Setenv("CAMEL_K_TEST_MAKE_DIR", "../../../")
-		ExpectExecSucceed(t, g, Make(t, "release-helm"))
 		ExpectExecSucceed(t, g,
 			exec.Command(
 				"helm",
@@ -55,7 +53,7 @@ func TestHelmInstallation(t *testing.T) {
 				"camel-k",
 				fmt.Sprintf("../../../docs/charts/camel-k-%s.tgz", defaults.Version),
 				"--set",
-				fmt.Sprintf("platform.build.registry.address=%s", KAMEL_INSTALL_REGISTRY),
+				fmt.Sprintf("platform.build.registry.address=%s", containerRegistry),
 				"--set",
 				"platform.build.registry.insecure=true",
 				"--set",
@@ -65,21 +63,22 @@ func TestHelmInstallation(t *testing.T) {
 				"--force",
 			),
 		)
+		// Refresh the test client to account for the newly installed CRDs
+		RefreshClient(t)
 
 		g.Eventually(OperatorPod(t, ctx, ns)).ShouldNot(BeNil())
-		// Check if restricted security context has been applyed
+		// Check if restricted security context has been applied
 		operatorPod := OperatorPod(t, ctx, ns)()
 		g.Expect(operatorPod.Spec.Containers[0].SecurityContext.RunAsNonRoot).To(Equal(kubernetes.DefaultOperatorSecurityContext().RunAsNonRoot))
 		g.Expect(operatorPod.Spec.Containers[0].SecurityContext.Capabilities).To(Equal(kubernetes.DefaultOperatorSecurityContext().Capabilities))
 		g.Expect(operatorPod.Spec.Containers[0].SecurityContext.SeccompProfile).To(Equal(kubernetes.DefaultOperatorSecurityContext().SeccompProfile))
 		g.Expect(operatorPod.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation).To(Equal(kubernetes.DefaultOperatorSecurityContext().AllowPrivilegeEscalation))
 
-		//Test a simple route
+		// Test a simple route
 		t.Run("simple route", func(t *testing.T) {
-			name := RandomizedSuffixName("yaml")
-			g.Expect(KamelRunWithID(t, ctx, operatorID, ns, "files/yaml.yaml", "--name", name).Execute()).To(Succeed())
-			g.Eventually(IntegrationPodPhase(t, ctx, ns, name), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
-			g.Eventually(IntegrationLogs(t, ctx, ns, name), TestTimeoutShort).Should(ContainSubstring("Magicstring!"))
+			g.Expect(KamelRunWithID(t, ctx, operatorID, ns, "files/yaml.yaml").Execute()).To(Succeed())
+			g.Eventually(IntegrationPodPhase(t, ctx, ns, "yaml"), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
+			g.Eventually(IntegrationLogs(t, ctx, ns, "yaml"), TestTimeoutShort).Should(ContainSubstring("Magicstring!"))
 		})
 
 		ExpectExecSucceed(t, g,
@@ -93,5 +92,10 @@ func TestHelmInstallation(t *testing.T) {
 		)
 
 		g.Eventually(OperatorPod(t, ctx, ns)).Should(BeNil())
+
+		// Test CRD uninstall (will remove Integrations as well)
+		UninstallCRDs(t, ctx, g, "../../../")
+
+		g.Eventually(CRDs(t)).Should(BeNil())
 	})
 }
