@@ -30,31 +30,6 @@ import (
 )
 
 func init() {
-	// Let's use the STAGING_RUNTIME_REPO if available
-	runtimeRepo := os.Getenv("STAGING_RUNTIME_REPO")
-	if runtimeRepo != "" {
-		KamelHooks = append(KamelHooks, func(args []string) []string {
-			if len(args) > 0 && args[0] == "install" {
-				args = append(args, fmt.Sprintf("--maven-repository=%s", runtimeRepo))
-			}
-			return args
-		})
-	}
-
-	// this hook can be also used to test a released version of the operator, e.g. the staging version during a voting period
-	// Uncomment the following lines and change references to enable the hook
-
-	// TestImageName = "docker.io/camelk/camel-k"
-	// TestImageVersion = "1.0.0-M2"
-
-	// KamelHooks = append(KamelHooks, func(args []string) []string {
-	//	if len(args) > 0 && args[0] == "install" {
-	//		args = append(args, "--operator-image=docker.io/camelk/camel-k:1.0.0-M2")
-	//		args = append(args, "--maven-repository=https://repository.apache.org/content/repositories/orgapachecamel-1156")
-	//	}
-	//	return args
-	// })
-
 	// Apply env vars for the test operator image to args if present
 	imageName := os.Getenv("CAMEL_K_TEST_IMAGE_NAME")
 	imageVersion := os.Getenv("CAMEL_K_TEST_IMAGE_VERSION")
