@@ -18,6 +18,8 @@ limitations under the License.
 package v1
 
 import (
+	"strings"
+
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -73,6 +75,14 @@ func (build *Build) BuilderDependencies() []string {
 	return []string{}
 }
 
+func (build *Build) RuntimeVersion() *string {
+	if builder, ok := FindBuilderTask(build.Spec.Tasks); ok {
+		return &builder.Runtime.Version
+	}
+
+	return nil
+}
+
 // FindBuilderTask returns the 1st builder task from the task list.
 func FindBuilderTask(tasks []Task) (*BuilderTask, bool) {
 	for _, t := range tasks {
@@ -272,11 +282,25 @@ func (bl BuildList) HasMatchingBuild(build *Build) (bool, *Build) {
 	if len(required) == 0 {
 		return false, nil
 	}
+	requiredMap := make(map[string]int, len(required))
+	for i, item := range required {
+		requiredMap[item] = i
+	}
+	runtimeVersion := build.RuntimeVersion()
 
-	for _, b := range bl.Items {
+	var bestBuild Build
+	bestBuildCommonDependencies := 0
+buildLoop:
+	for i := range bl.Items {
+		b := bl.Items[i]
 		if b.Name == build.Name || b.Status.IsFinished() {
 			continue
 		}
+		bRuntimeVersion := b.RuntimeVersion()
+
+		if *runtimeVersion != *bRuntimeVersion {
+			continue
+		}
 
 		dependencies := b.BuilderDependencies()
 		dependencyMap := make(map[string]int, len(dependencies))
@@ -284,40 +308,62 @@ func (bl BuildList) HasMatchingBuild(build *Build) (bool, *Build) {
 			dependencyMap[item] = i
 		}
 
-		allMatching := true
-		missing := 0
-		for _, item := range required {
-			if _, ok := dependencyMap[item]; !ok {
-				allMatching = false
-				missing++
+		// check if this build has any extra dependency. If it does, we can't use it
+		for _, item := range dependencies {
+			if _, ok := requiredMap[item]; !ok {
+				continue buildLoop
 			}
 		}
 
-		// Heuristic approach: if there are too many unrelated libraries then this image is
-		// not suitable to be used as base image
-		if !allMatching && missing > len(required)/2 {
+		// now check how many common dependencies this build has
+		missing := 0
+		commonDependencies := 0
+		for _, item := range required {
+			if _, ok := dependencyMap[item]; !ok {
+				missing++
+			} else {
+				commonDependencies++
+			}
+		}
+
+		if commonDependencies == 0 {
+			// no common dependencies
 			continue
 		}
 
-		// handle suitable build that has started already
-		if b.Status.Phase == BuildPhasePending || b.Status.Phase == BuildPhaseRunning {
+		switch b.Status.Phase {
+		case BuildPhasePending, BuildPhaseRunning:
+			// handle suitable build that has started already
 			return true, &b
-		}
+		case BuildPhaseInitialization, BuildPhaseScheduling:
+			// handle suitable scheduled build
 
-		// handle suitable scheduled build
-		if b.Status.Phase == BuildPhaseInitialization || b.Status.Phase == BuildPhaseScheduling {
-			if allMatching && len(required) == len(dependencies) {
+			if missing == 0 {
 				// seems like both builds require exactly the same list of dependencies
 				// additionally check for the creation timestamp
-				if b.CreationTimestamp.Before(&build.CreationTimestamp) {
+				if compareBuilds(&b, build) < 0 {
 					return true, &b
 				}
-			} else if missing > 0 {
-				// found another suitable scheduled build with fewer dependencies that should build first in order to reuse the produced image
-				return true, &b
+			} else if commonDependencies > bestBuildCommonDependencies {
+				bestBuildCommonDependencies = commonDependencies
+				bestBuild = b
+				continue
 			}
 		}
 	}
 
+	if bestBuildCommonDependencies > 0 {
+		return true, &bestBuild
+	}
 	return false, nil
 }
+
+func compareBuilds(b1 *Build, b2 *Build) int {
+	if b1.CreationTimestamp.Before(&b2.CreationTimestamp) {
+		return -1
+	}
+	if b2.CreationTimestamp.Before(&b1.CreationTimestamp) {
+		return 1
+	}
+	return strings.Compare(b1.Name, b2.Name)
+}
