@@ -19,46 +19,47 @@ package knative
 
 import "fmt"
 
-// CamelEnvironment is the top level configuration object expected by the Camel Knative component
+// CamelEnvironment is the top level configuration object expected by the Camel Knative component.
 type CamelEnvironment struct {
 	Services []CamelServiceDefinition `json:"services"`
 }
 
-// NewCamelEnvironment creates a new env
+// NewCamelEnvironment creates a new env.
 func NewCamelEnvironment() CamelEnvironment {
 	return CamelEnvironment{
 		Services: make([]CamelServiceDefinition, 0),
 	}
 }
 
-// CamelServiceDefinition defines the parameters to connect to Knative service. It's also used for exposed services
+// CamelServiceDefinition defines the parameters to connect to Knative service. It's also used for exposed services.
 type CamelServiceDefinition struct {
 	ServiceType CamelServiceType  `json:"type"`
 	Name        string            `json:"name"`
 	URL         string            `json:"url,omitempty"`
 	Path        string            `json:"path,omitempty"`
 	Metadata    map[string]string `json:"metadata,omitempty"`
+	SinkBinding bool              `json:"sinkBinding,omitempty"`
 }
 
-// CamelEndpointKind --
+// CamelEndpointKind -- .
 type CamelEndpointKind string
 
 const (
-	// CamelEndpointKindSource is a service that can be used to consume events
+	// CamelEndpointKindSource is a service that can be used to consume events.
 	CamelEndpointKindSource CamelEndpointKind = "source"
-	// CamelEndpointKindSink is a service that can be used to send events to
+	// CamelEndpointKindSink is a service that can be used to send events to.
 	CamelEndpointKindSink CamelEndpointKind = "sink"
 )
 
-// CamelServiceType --
+// CamelServiceType -- .
 type CamelServiceType string
 
 const (
-	// CamelServiceTypeEndpoint is a callable endpoint
+	// CamelServiceTypeEndpoint is a callable endpoint.
 	CamelServiceTypeEndpoint CamelServiceType = "endpoint"
-	// CamelServiceTypeChannel is a callable endpoint that will be also associated to a subscription
+	// CamelServiceTypeChannel is a callable endpoint that will be also associated to a subscription.
 	CamelServiceTypeChannel CamelServiceType = "channel"
-	// CamelServiceTypeEvent is used when the target service is the Knative broker
+	// CamelServiceTypeEvent is used when the target service is the Knative broker.
 	CamelServiceTypeEvent CamelServiceType = "event"
 )
 
@@ -70,7 +71,7 @@ func (s CamelServiceType) ResourceDescription(subject string) string {
 	return fmt.Sprintf("%s%s %s", prefix, string(s), subject)
 }
 
-// Meta Options
+// Meta Options.
 const (
 	CamelMetaKnativeKind       = "knative.kind"
 	CamelMetaKnativeAPIVersion = "knative.apiVersion"
