@@ -17,7 +17,7 @@ limitations under the License.
 
 package trait
 
-// Base type for all traits.
+// Trait is the base type for all traits. It could be disabled by the user.
 type Trait struct {
 	// Can be used to enable or disable a trait. All traits share this common property.
 	Enabled *bool `property:"enabled" json:"enabled,omitempty"`
@@ -27,11 +27,22 @@ type Trait struct {
 	Configuration *Configuration `json:"configuration,omitempty"`
 }
 
+// PlatformBaseTrait is the base type for platform traits. It cannot be disabled by the user.
+type PlatformBaseTrait struct {
+	// Deprecated: no longer in use.
+	Enabled *bool `property:"enabled" json:"enabled,omitempty"`
+	// Legacy trait configuration parameters.
+	// Deprecated: for backward compatibility.
+	Configuration *Configuration `json:"configuration,omitempty"`
+}
+
+// Configuration defines the trait structure
 // Deprecated: for backward compatibility.
 type Configuration struct {
 	RawMessage `json:",inline"`
 }
 
+// RawMessage defines a binary type for configuration
 // +kubebuilder:validation:Type=object
 // +kubebuilder:validation:Format=""
 // +kubebuilder:pruning:PreserveUnknownFields
