@@ -18,32 +18,23 @@ limitations under the License.
 package cmd
 
 import (
-	"archive/zip"
 	"context"
 	"errors"
 
 	// this is needed to generate an SHA1 sum for Jars
 	// #nosec G501
-	"crypto/md5"
+
 	// #nosec G505
-	"crypto/sha1"
-	"encoding/hex"
+
 	"encoding/json"
-	"encoding/xml"
 	"fmt"
-	"hash"
-	"io"
-	"io/fs"
 	"net/url"
 	"os"
 	"os/signal"
-	"path/filepath"
 	"reflect"
-	"regexp"
 	"strings"
 	"syscall"
 
-	spectrum "github.com/container-tools/spectrum/pkg/builder"
 	"github.com/magiconair/properties"
 
 	"github.com/spf13/cobra"
@@ -61,15 +52,11 @@ import (
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/cmd/source"
-	"github.com/apache/camel-k/v2/pkg/platform"
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
-	"github.com/apache/camel-k/v2/pkg/util/defaults"
-	"github.com/apache/camel-k/v2/pkg/util/dsl"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	k8slog "github.com/apache/camel-k/v2/pkg/util/kubernetes/log"
-	"github.com/apache/camel-k/v2/pkg/util/maven"
 	"github.com/apache/camel-k/v2/pkg/util/property"
 	"github.com/apache/camel-k/v2/pkg/util/resource"
 	"github.com/apache/camel-k/v2/pkg/util/sync"
@@ -95,14 +82,22 @@ func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions)
 
 	cmd.Flags().String("name", "", "The integration name")
 	cmd.Flags().String("image", "", "An image built externally (ie, via CICD). Enabling it will skip the Integration build phase.")
-	cmd.Flags().StringArrayP("connect", "c", nil, "A Service that the integration should bind to, specified as [[apigroup/]version:]kind:[namespace/]name")
+	// Deprecated: service binding parameter won't be supported in future releases.
+	cmd.Flags().StringArrayP("connect", "c", nil, "A Service that the integration should bind to, specified as [[apigroup/]version:]kind:[namespace/]name."+
+		"Deprecated: service binding won't be supported in future releases.")
 	cmd.Flags().StringArrayP("dependency", "d", nil, `A dependency that should be included, e.g., "-d camel:mail" for a Camel component, "-d mvn:org.my:app:1.0" for a Maven dependency`)
 	cmd.Flags().BoolP("wait", "w", false, "Wait for the integration to be running")
 	cmd.Flags().StringP("kit", "k", "", "The kit used to run the integration")
-	cmd.Flags().StringArrayP("property", "p", nil, "Add a runtime property or properties file from a path, a config map or a secret (syntax: [my-key=my-value|file:/path/to/my-conf.properties|[configmap|secret]:name])")
-	cmd.Flags().StringArray("build-property", nil, "Add a build time property or properties file from a path, a config map or a secret (syntax: [my-key=my-value|file:/path/to/my-conf.properties|[configmap|secret]:name]])")
-	cmd.Flags().StringArray("config", nil, "Add a runtime configuration from a Configmap or a Secret (syntax: [configmap|secret]:name[/key], where name represents the configmap/secret name and key optionally represents the configmap/secret key to be filtered)")
-	cmd.Flags().StringArray("resource", nil, "Add a runtime resource from a Configmap or a Secret (syntax: [configmap|secret]:name[/key][@path], where name represents the configmap/secret name, key optionally represents the configmap/secret key to be filtered and path represents the destination path)")
+	cmd.Flags().StringArrayP("property", "p", nil, "Add a runtime property or a local properties file from a path "+
+		"(syntax: [my-key=my-value|file:/path/to/my-conf.properties])")
+	cmd.Flags().StringArray("build-property", nil, "Add a build time property or properties file from a path "+
+		"(syntax: [my-key=my-value|file:/path/to/my-conf.properties])")
+	cmd.Flags().StringArray("config", nil, "Add a runtime configuration from a Configmap or a Secret "+
+		"(syntax: [configmap|secret]:name[/key], where name represents the configmap/secret name and key optionally "+
+		"represents the configmap/secret key to be filtered)")
+	cmd.Flags().StringArray("resource", nil, "Add a runtime resource from a Configmap or a Secret "+
+		"(syntax: [configmap|secret]:name[/key][@path], where name represents the configmap/secret name, "+
+		"key optionally represents the configmap/secret key to be filtered and path represents the destination path)")
 	cmd.Flags().StringArray("maven-repository", nil, "Add a maven repository")
 	cmd.Flags().Bool("logs", false, "Print integration logs")
 	cmd.Flags().Bool("sync", false, "Synchronize the local source file with the cluster, republishing at each change")
@@ -134,38 +129,41 @@ func newCmdRun(rootCmdOptions *RootCmdOptions) (*cobra.Command, *runCmdOptions)
 
 type runCmdOptions struct {
 	*RootCmdOptions    `json:"-"`
-	Compression        bool     `mapstructure:"compression" yaml:",omitempty"`
-	Wait               bool     `mapstructure:"wait" yaml:",omitempty"`
-	Logs               bool     `mapstructure:"logs" yaml:",omitempty"`
-	Sync               bool     `mapstructure:"sync" yaml:",omitempty"`
-	Dev                bool     `mapstructure:"dev" yaml:",omitempty"`
-	UseFlows           bool     `mapstructure:"use-flows" yaml:",omitempty"`
-	Save               bool     `mapstructure:"save" yaml:",omitempty" kamel:"omitsave"`
-	IntegrationKit     string   `mapstructure:"kit" yaml:",omitempty"`
-	IntegrationName    string   `mapstructure:"name" yaml:",omitempty"`
-	ContainerImage     string   `mapstructure:"image" yaml:",omitempty"`
-	Profile            string   `mapstructure:"profile" yaml:",omitempty"`
-	IntegrationProfile string   `mapstructure:"integration-profile" yaml:",omitempty"`
-	OperatorID         string   `mapstructure:"operator-id" yaml:",omitempty"`
-	OutputFormat       string   `mapstructure:"output" yaml:",omitempty"`
-	PodTemplate        string   `mapstructure:"pod-template" yaml:",omitempty"`
-	ServiceAccount     string   `mapstructure:"service-account" yaml:",omitempty"`
-	Connects           []string `mapstructure:"connects" yaml:",omitempty"`
-	Resources          []string `mapstructure:"resources" yaml:",omitempty"`
-	OpenAPIs           []string `mapstructure:"open-apis" yaml:",omitempty"`
-	Dependencies       []string `mapstructure:"dependencies" yaml:",omitempty"`
-	Properties         []string `mapstructure:"properties" yaml:",omitempty"`
-	BuildProperties    []string `mapstructure:"build-properties" yaml:",omitempty"`
-	Configs            []string `mapstructure:"configs" yaml:",omitempty"`
-	Repositories       []string `mapstructure:"maven-repositories" yaml:",omitempty"`
-	Traits             []string `mapstructure:"traits" yaml:",omitempty"`
-	Volumes            []string `mapstructure:"volumes" yaml:",omitempty"`
-	EnvVars            []string `mapstructure:"envs" yaml:",omitempty"`
-	Labels             []string `mapstructure:"labels" yaml:",omitempty"`
-	Annotations        []string `mapstructure:"annotations" yaml:",omitempty"`
-	Sources            []string `mapstructure:"sources" yaml:",omitempty"`
-	RegistryOptions    url.Values
-	Force              bool `mapstructure:"force" yaml:",omitempty"`
+	Compression        bool   `mapstructure:"compression" yaml:",omitempty"`
+	Wait               bool   `mapstructure:"wait" yaml:",omitempty"`
+	Logs               bool   `mapstructure:"logs" yaml:",omitempty"`
+	Sync               bool   `mapstructure:"sync" yaml:",omitempty"`
+	Dev                bool   `mapstructure:"dev" yaml:",omitempty"`
+	UseFlows           bool   `mapstructure:"use-flows" yaml:",omitempty"`
+	Save               bool   `mapstructure:"save" yaml:",omitempty" kamel:"omitsave"`
+	IntegrationKit     string `mapstructure:"kit" yaml:",omitempty"`
+	IntegrationName    string `mapstructure:"name" yaml:",omitempty"`
+	ContainerImage     string `mapstructure:"image" yaml:",omitempty"`
+	Profile            string `mapstructure:"profile" yaml:",omitempty"`
+	IntegrationProfile string `mapstructure:"integration-profile" yaml:",omitempty"`
+	OperatorID         string `mapstructure:"operator-id" yaml:",omitempty"`
+	OutputFormat       string `mapstructure:"output" yaml:",omitempty"`
+	PodTemplate        string `mapstructure:"pod-template" yaml:",omitempty"`
+	ServiceAccount     string `mapstructure:"service-account" yaml:",omitempty"`
+	// Deprecated: service binding parameter won't be supported in future releases.
+	Connects  []string `mapstructure:"connects" yaml:",omitempty"`
+	Resources []string `mapstructure:"resources" yaml:",omitempty"`
+	// Deprecated: openapi parameter won't be supported in future releases.
+	OpenAPIs        []string `mapstructure:"open-apis" yaml:",omitempty"`
+	Dependencies    []string `mapstructure:"dependencies" yaml:",omitempty"`
+	Properties      []string `mapstructure:"properties" yaml:",omitempty"`
+	BuildProperties []string `mapstructure:"build-properties" yaml:",omitempty"`
+	Configs         []string `mapstructure:"configs" yaml:",omitempty"`
+	Repositories    []string `mapstructure:"maven-repositories" yaml:",omitempty"`
+	Traits          []string `mapstructure:"traits" yaml:",omitempty"`
+	Volumes         []string `mapstructure:"volumes" yaml:",omitempty"`
+	EnvVars         []string `mapstructure:"envs" yaml:",omitempty"`
+	Labels          []string `mapstructure:"labels" yaml:",omitempty"`
+	Annotations     []string `mapstructure:"annotations" yaml:",omitempty"`
+	Sources         []string `mapstructure:"sources" yaml:",omitempty"`
+	// Deprecated: registry parameter no longer in use.
+	RegistryOptions url.Values
+	Force           bool `mapstructure:"force" yaml:",omitempty"`
 }
 
 func (o *runCmdOptions) decode(cmd *cobra.Command, args []string) error {
@@ -288,6 +286,23 @@ func (o *runCmdOptions) validate(cmd *cobra.Command) error {
 		}
 	}
 
+	for i, property := range o.Properties {
+		// We support only --config
+		if strings.HasPrefix(property, "configmap:") || strings.HasPrefix(property, "secret:") {
+			o.Configs = append(o.Configs, property)
+			// clean it to avoid further processing
+			o.Properties[i] = ""
+			fmt.Fprintf(cmd.OutOrStdout(), "Property %s is deprecated: use --config %s instead\n", property, property)
+		}
+	}
+
+	for _, bp := range o.BuildProperties {
+		// Deprecated: to be removed
+		if strings.HasPrefix(bp, "configmap:") || strings.HasPrefix(bp, "secret:") {
+			fmt.Fprintf(cmd.OutOrStdout(), "Build property %s is deprecated. It will be removed from future releases.\n", bp)
+		}
+	}
+
 	var client client.Client
 	if !isOfflineCommand(cmd) {
 		client, err = o.GetCmdClient()
@@ -552,7 +567,7 @@ func (o *runCmdOptions) createOrUpdateIntegration(cmd *cobra.Command, c client.C
 		return nil, err
 	}
 
-	if err := o.applyDependencies(cmd, c, integration, name); err != nil {
+	if err := o.applyDependencies(cmd, integration); err != nil {
 		return nil, err
 	}
 
@@ -606,14 +621,6 @@ func showIntegrationOutput(cmd *cobra.Command, integration *v1.Integration, outp
 	return printer.PrintObj(integration, cmd.OutOrStdout())
 }
 
-func showIntegrationKitOutput(cmd *cobra.Command, integrationKit *v1.IntegrationKit, outputFormat string) error {
-	printer := printers.NewTypeSetter(scheme.Scheme)
-	printer.Delegate = &kubernetes.CLIPrinter{
-		Format: outputFormat,
-	}
-	return printer.PrintObj(integrationKit, cmd.OutOrStdout())
-}
-
 func (o *runCmdOptions) getIntegration(cmd *cobra.Command, c client.Client, namespace, name string) (*v1.Integration, *v1.Integration, error) {
 	it := &v1.Integration{
 		TypeMeta: metav1.TypeMeta{
@@ -693,7 +700,7 @@ func (o *runCmdOptions) resolveSources(cmd *cobra.Command, sources []string, it
 
 	for _, source := range resolvedSources {
 		if o.UseFlows && !o.Compression && source.IsYaml() {
-			flows, err := dsl.FromYamlDSLString(source.Content)
+			flows, err := v1.FromYamlDSLString(source.Content)
 			if err != nil {
 				return err
 			}
@@ -819,69 +826,31 @@ func (o *runCmdOptions) convertToTraitParameter(c client.Client, value, traitPar
 	return traits, nil
 }
 
-func (o *runCmdOptions) applyDependencies(cmd *cobra.Command, c client.Client, it *v1.Integration, name string) error {
-	var platform *v1.IntegrationPlatform
+func (o *runCmdOptions) applyDependencies(cmd *cobra.Command, it *v1.Integration) error {
 	var catalog *camel.RuntimeCatalog
 	for _, item := range o.Dependencies {
-		// Deprecated: won't be supported in future releases
-		if strings.HasPrefix(item, "file://") || strings.HasPrefix(item, "http://") || strings.HasPrefix(item, "https://") {
-			if platform == nil {
-				var err error
-				platform, err = o.getPlatform(cmd, c, it)
-				if err != nil {
-					return err
-				}
+		if catalog == nil {
+			// The catalog used for lightweight validation of Camel components.
+			// The exact runtime version is not used here since resolving the runtime version may be
+			// a costly operation and most of the use cases should be covered by the default catalog.
+			// And the validation only warns potential misusage of Camel components at the CLI level,
+			// so strictness of catalog version is not necessary here.
+			var err error
+			catalog, err = createCamelCatalog()
+			if err != nil {
+				return err
 			}
-			fmt.Fprintf(cmd.ErrOrStderr(), "Warning: this feature is deprecated and may disappear in future release. Use jvm trait instead.\n")
-			if err := o.uploadDependency(platform, item, name, cmd, it); err != nil {
-				return fmt.Errorf("error trying to upload %s to the Image Registry.: %w", item, err)
-			}
-		} else {
 			if catalog == nil {
-				// The catalog used for lightweight validation of Camel components.
-				// The exact runtime version is not used here since resolving the runtime version may be
-				// a costly operation and most of the use cases should be covered by the default catalog.
-				// And the validation only warns potential misusage of Camel components at the CLI level,
-				// so strictness of catalog version is not necessary here.
-				var err error
-				catalog, err = createCamelCatalog()
-				if err != nil {
-					return err
-				}
-				if catalog == nil {
-					return fmt.Errorf("error trying to load the default Camel catalog")
-				}
+				return fmt.Errorf("error trying to load the default Camel catalog")
 			}
-			addDependency(cmd, it, item, catalog)
 		}
+		addDependency(cmd, it, item, catalog)
+
 	}
 
 	return nil
 }
 
-func (o *runCmdOptions) getPlatform(cmd *cobra.Command, c client.Client, it *v1.Integration) (*v1.IntegrationPlatform, error) {
-	// let's also enable the registry trait if not explicitly disabled
-	if !util.StringSliceContainsAnyOf(o.Traits, "registry.enabled=false") {
-		o.Traits = append(o.Traits, "registry.enabled=true")
-	}
-	pl, err := platform.GetForResource(o.Context, c, it)
-	if err != nil {
-		return nil, err
-	}
-	if ca := pl.Status.Build.Registry.CA; ca != "" {
-		o.PrintfVerboseOutf(cmd, "We've noticed the image registry is configured with a custom certificate [%s] \n", ca)
-		o.PrintVerboseOut(cmd, "Please make sure Kamel CLI is configured to use it or the operation will fail.")
-		o.PrintVerboseOut(cmd, "More information can be found here https://nodejs.org/api/cli.html#cli_node_extra_ca_certs_file")
-	}
-	if secret := pl.Status.Build.Registry.Secret; secret != "" {
-		o.PrintfVerboseOutf(cmd, "We've noticed the image registry is configured with a Secret [%s] \n", secret)
-		o.PrintVerboseOut(cmd, "Please configure Docker authentication correctly or the operation will fail (by default it's $HOME/.docker/config.json).")
-		o.PrintVerboseOut(cmd, "More information can be found here https://docs.docker.com/engine/reference/commandline/login/")
-	}
-
-	return pl, nil
-}
-
 func (o *runCmdOptions) GetIntegrationName(sources []string) string {
 	name := ""
 	switch {
@@ -979,405 +948,3 @@ func resolvePodTemplate(ctx context.Context, cmd *cobra.Command, templateSrc str
 	}
 	return err
 }
-
-func parseFileURI(uri string) *url.URL {
-	file := new(url.URL)
-	file.Scheme = "file"
-	path := strings.TrimPrefix(uri, "file://")
-	i := strings.IndexByte(path, '?')
-	if i > 0 {
-		file.Path = path[:i]
-		file.RawQuery = path[i+1:]
-	} else {
-		file.Path = path
-	}
-	return file
-}
-
-func (o *runCmdOptions) getRegistry(platform *v1.IntegrationPlatform) string {
-	registry := o.RegistryOptions.Get("registry")
-	if registry != "" {
-		return registry
-	}
-	return platform.Status.Build.Registry.Address
-}
-
-func (o *runCmdOptions) skipChecksums() bool {
-	return o.RegistryOptions.Get("skipChecksums") == "true"
-}
-
-func (o *runCmdOptions) skipPom() bool {
-	return o.RegistryOptions.Get("skipPOM") == "true"
-}
-
-func (o *runCmdOptions) classpath() bool {
-	return o.RegistryOptions.Get("classpath") == "true"
-}
-
-func (o *runCmdOptions) getTargetPath() string {
-	return o.RegistryOptions.Get("targetPath")
-}
-
-// Deprecated: won't be supported in future releases.
-func (o *runCmdOptions) uploadDependency(platform *v1.IntegrationPlatform, item string, integrationName string, cmd *cobra.Command, integration *v1.Integration) error {
-	var localPath string
-	if strings.HasPrefix(item, "http://") || strings.HasPrefix(item, "https://") {
-		idx := strings.LastIndex(item, "|")
-		var depURL string
-		if idx == -1 {
-			depURL = item
-			o.RegistryOptions = make(url.Values)
-		} else {
-			query := item[idx+1:]
-			options, err := url.ParseQuery(query)
-			if err != nil {
-				return fmt.Errorf("invalid http dependency options %s: %w", query, err)
-			}
-			o.RegistryOptions = options
-			depURL = item[:idx]
-		}
-
-		uri, err := url.Parse(depURL)
-		if err != nil {
-			return fmt.Errorf("invalid http dependency url %s: %w", depURL, err)
-		} else if localPath, err = downloadDependency(o.Context, *uri); err != nil {
-			return fmt.Errorf("could not download http dependency %s: %w", depURL, err)
-		}
-		// Remove the temporary file
-		defer os.Remove(localPath)
-	} else {
-		uri := parseFileURI(item)
-		o.RegistryOptions = uri.Query()
-		localPath = uri.Path
-	}
-	targetPath := o.getTargetPath()
-	options := o.getSpectrumOptions(platform, cmd)
-	dirName, err := getDirName(localPath)
-	if err != nil {
-		return err
-	}
-
-	return filepath.WalkDir(localPath, func(path string, d fs.DirEntry, err error) error {
-		if err != nil {
-			return err
-		}
-		if d.IsDir() {
-			return nil
-		}
-		// Let's try to build a default Maven GAV from the path
-		gav, err := createDefaultGav(path, dirName, integrationName)
-		if err != nil {
-			return err
-		}
-		// When uploading, there are three cases: POM files, JAR files and the rest which will be mounted on the filesystem
-		switch {
-		case isPom(path):
-			gav := extractGavFromPom(path, gav)
-			return o.uploadAsMavenArtifact(gav, path, platform, integration.Namespace, options, cmd)
-		case isJar(path):
-			// Try to upload pom in JAR and extract it's GAV
-			gav = o.uploadPomFromJar(gav, path, platform, integration.Namespace, options, cmd)
-			// add JAR to dependency list
-			dependency := fmt.Sprintf("mvn:%s:%s:%s:%s", gav.GroupID, gav.ArtifactID, gav.Type, gav.Version)
-			o.PrintfVerboseOutf(cmd, "Added %s to the Integration's dependency list \n", dependency)
-			integration.Spec.AddDependency(dependency)
-			// Upload JAR
-			return o.uploadAsMavenArtifact(gav, path, platform, integration.Namespace, options, cmd)
-		default:
-			mountPath, err := getMountPath(targetPath, dirName, path)
-			if err != nil {
-				return err
-			}
-			dependency := fmt.Sprintf("registry-mvn:%s:%s:%s:%s@%s", gav.GroupID, gav.ArtifactID, gav.Type, gav.Version, mountPath)
-			if o.classpath() {
-				dependency = fmt.Sprintf("%s@%s", dependency, "classpath")
-			}
-			o.PrintfVerboseOutf(cmd, "Added %s to the Integration's dependency list \n", dependency)
-			integration.Spec.AddDependency(dependency)
-			return o.uploadAsMavenArtifact(gav, path, platform, integration.Namespace, options, cmd)
-		}
-	})
-}
-
-func getMountPath(targetPath string, dirName string, path string) (string, error) {
-	// if the target path is a file then use that as the exact mount path
-	if filepath.Ext(targetPath) != "" {
-		return targetPath, nil
-	}
-	// else build a mount path based on the filename relative to the base directory
-	// (in case we are uploading multiple files with the same name)
-	localRelativePath, err := filepath.Rel(dirName, path)
-	if err != nil {
-		return "", err
-	}
-	return filepath.Join(targetPath, localRelativePath), nil
-}
-
-func (o *runCmdOptions) uploadPomFromJar(gav maven.Dependency, path string, platform *v1.IntegrationPlatform, ns string, options spectrum.Options, cmd *cobra.Command) maven.Dependency {
-	_ = util.WithTempDir("camel-k", func(tmpDir string) error {
-		pomPath := filepath.Join(tmpDir, "pom.xml")
-		jar, err := zip.OpenReader(path)
-		if err != nil {
-			return err
-		}
-		defer jar.Close()
-		regPom := regexp.MustCompile(`META-INF/maven/.*/.*/pom\.xml`)
-		regPomProperties := regexp.MustCompile(`META-INF/maven/.*/.*/pom\.properties`)
-		foundPom := false
-		foundProperties := false
-		pomExtracted := false
-		for _, f := range jar.File {
-			if regPom.MatchString(f.Name) {
-				foundPom = true
-				pomExtracted = extractFromZip(pomPath, f)
-			} else if regPomProperties.MatchString(f.Name) {
-				foundProperties = true
-				if dep, ok := o.extractGav(f, path, cmd); ok {
-					gav = dep
-				}
-			}
-			if foundPom && foundProperties {
-				break
-			}
-		}
-		if pomExtracted {
-			if o.skipPom() {
-				o.PrintfVerboseOutf(cmd, "Skipping uploading extracted POM from %s \n", path)
-			} else {
-				gav.Type = "pom"
-				// Swallow error as this is not a mandatory step
-				_ = o.uploadAsMavenArtifact(gav, pomPath, platform, ns, options, cmd)
-			}
-		}
-		return nil
-	})
-	gav.Type = "jar"
-	return gav
-}
-
-func extractFromZip(dst string, src *zip.File) bool {
-	file, err := os.Create(dst)
-	if err != nil {
-		return false
-	}
-	defer file.Close()
-	rc, err := src.Open()
-	if err != nil {
-		return false
-	}
-	defer rc.Close()
-	// no DoS on client side
-	// #nosec G110
-	_, err = io.Copy(file, rc)
-	return err == nil
-}
-
-func (o *runCmdOptions) extractGav(src *zip.File, localPath string, cmd *cobra.Command) (maven.Dependency, bool) {
-	rc, err := src.Open()
-	if err != nil {
-		return maven.Dependency{}, false
-	}
-	defer rc.Close()
-	data, err := io.ReadAll(rc)
-	if err != nil {
-		o.PrintfVerboseErrf(cmd, "Error while reading pom.properties from [%s], switching to default: \n %s err \n", localPath, err)
-		return maven.Dependency{}, false
-	}
-	prop, err := properties.Load(data, properties.UTF8)
-	if err != nil {
-		o.PrintfVerboseErrf(cmd, "Error while reading pom.properties from [%s], switching to default: \n %s err \n", localPath, err)
-		return maven.Dependency{}, false
-	}
-
-	groupID, ok := prop.Get("groupId")
-	if !ok {
-		o.PrintfVerboseErrf(cmd, "Couldn't find groupId property while reading pom.properties from [%s], switching to default \n", localPath)
-		return maven.Dependency{}, false
-	}
-	artifactID, ok := prop.Get("artifactId")
-	if !ok {
-		o.PrintfVerboseErrf(cmd, "Couldn't find artifactId property while reading pom.properties from [%s], switching to default \n", localPath)
-		return maven.Dependency{}, false
-	}
-	version, ok := prop.Get("version")
-	if !ok {
-		o.PrintfVerboseErrf(cmd, "Couldn't find version property while reading pom.properties from [%s], switching to default \n", localPath)
-		return maven.Dependency{}, false
-	}
-	return maven.Dependency{
-		GroupID:    groupID,
-		ArtifactID: artifactID,
-		Type:       "jar",
-		Version:    version,
-	}, true
-}
-
-func (o *runCmdOptions) uploadAsMavenArtifact(dependency maven.Dependency, path string, platform *v1.IntegrationPlatform, ns string, options spectrum.Options, cmd *cobra.Command) error {
-	artifactHTTPPath := getArtifactHTTPPath(dependency, platform, ns)
-	options.Target = fmt.Sprintf("%s/%s:%s", o.getRegistry(platform), artifactHTTPPath, dependency.Version)
-	_, err := spectrum.Build(options, fmt.Sprintf("%s:.", path))
-	if err != nil {
-		return err
-	}
-	o.PrintfVerboseOutf(cmd, "Uploaded: %s to %s \n", path, options.Target)
-	if o.skipChecksums() {
-		o.PrintfVerboseOutf(cmd, "Skipping generating and uploading checksum files for %s \n", path)
-		return nil
-	}
-	return o.uploadChecksumFiles(path, options, platform, artifactHTTPPath, dependency)
-}
-
-// Currently swallows errors because our Project model is incomplete.
-// Most of the time it is irrelevant for our use case (GAV).
-//
-//nolint:errcheck
-func extractGavFromPom(path string, gav maven.Dependency) maven.Dependency {
-	var project maven.Project
-	file, err := os.Open(path)
-	if err != nil {
-		return gav
-	}
-	defer file.Close()
-	content, err := io.ReadAll(file)
-	if err != nil {
-		return gav
-	}
-	xml.Unmarshal(content, &project)
-	if project.GroupID != "" {
-		gav.GroupID = project.GroupID
-	}
-	if project.ArtifactID != "" {
-		gav.ArtifactID = project.ArtifactID
-	}
-	if project.Version != "" {
-		gav.Version = project.Version
-	}
-	gav.Type = "pom"
-	return gav
-}
-
-//nolint:gosec
-func (o *runCmdOptions) uploadChecksumFiles(path string, options spectrum.Options, platform *v1.IntegrationPlatform, artifactHTTPPath string, dependency maven.Dependency) error {
-	return util.WithTempDir("camel-k", func(tmpDir string) error {
-		if err := o.uploadChecksumFile(md5.New(), tmpDir, "_md5", path, options, platform, artifactHTTPPath, dependency); err != nil {
-			return err
-		}
-		return o.uploadChecksumFile(sha1.New(), tmpDir, "_sha1", path, options, platform, artifactHTTPPath, dependency)
-	})
-}
-
-func (o *runCmdOptions) uploadChecksumFile(hash hash.Hash, tmpDir string, ext string, path string, options spectrum.Options, platform *v1.IntegrationPlatform, artifactHTTPPath string, dependency maven.Dependency) error {
-	file, err := os.Open(path)
-	if err != nil {
-		return err
-	}
-	defer file.Close()
-	_, err = io.Copy(hash, file)
-	if err != nil {
-		return err
-	}
-
-	filename := "maven_" + filepath.Base(path) + ext
-	filepath := filepath.Join(tmpDir, filename)
-
-	if err = writeChecksumToFile(filepath, hash); err != nil {
-		return err
-	}
-	options.Target = fmt.Sprintf("%s/%s%s:%s", o.getRegistry(platform), artifactHTTPPath, ext, dependency.Version)
-	_, err = spectrum.Build(options, fmt.Sprintf("%s:.", filepath))
-	return err
-}
-
-func writeChecksumToFile(filepath string, hash hash.Hash) error {
-	file, err := os.Create(filepath)
-	if err != nil {
-		return err
-	}
-	defer file.Close()
-
-	_, err = file.WriteString(hex.EncodeToString(hash.Sum(nil)))
-	return err
-}
-
-func (o *runCmdOptions) getSpectrumOptions(platform *v1.IntegrationPlatform, cmd *cobra.Command) spectrum.Options {
-	insecure := platform.Status.Build.Registry.Insecure
-	var stdout io.Writer
-	if o.Verbose {
-		stdout = cmd.OutOrStdout()
-	}
-	options := spectrum.Options{
-		PullInsecure:  true,
-		PushInsecure:  insecure,
-		PullConfigDir: "",
-		PushConfigDir: "",
-		Base:          "",
-		Stdout:        stdout,
-		Stderr:        cmd.OutOrStderr(),
-		Recursive:     false,
-	}
-	return options
-}
-
-func getArtifactHTTPPath(dependency maven.Dependency, platform *v1.IntegrationPlatform, ns string) string {
-	artifactHTTPPath := fmt.Sprintf("maven_%s_%s_%s_%s-%s_%s", dependency.GroupID, dependency.ArtifactID, dependency.Version, dependency.ArtifactID, dependency.Version, dependency.Type)
-	// Image repository names must be lower cased
-	artifactHTTPPath = strings.ToLower(artifactHTTPPath)
-	// Some vendors don't allow '/' or '.' in repository name so let's replace them with '_'
-	artifactHTTPPath = strings.ReplaceAll(artifactHTTPPath, "/", "_")
-	artifactHTTPPath = strings.ReplaceAll(artifactHTTPPath, ".", "_")
-	organization := platform.Status.Build.Registry.Organization
-	if organization == "" {
-		organization = ns
-	}
-	return fmt.Sprintf("%s/%s", organization, artifactHTTPPath)
-}
-
-func createDefaultGav(path string, dirName string, integrationName string) (maven.Dependency, error) {
-	// let's set the default ArtifactId using the integration name and the file's relative path
-	// we use the relative path in case of nested files that might have the same name
-	// we replace the file seperators with dots to comply with Maven GAV naming conventions.
-	fileRelPath, ext, err := getFileRelativePathAndExtension(path, dirName)
-	if err != nil {
-		return maven.Dependency{}, err
-	}
-
-	defaultArtifactID := integrationName + "-" + strings.ReplaceAll(fileRelPath, string(os.PathSeparator), ".")
-	defaultGroupID := "org.apache.camel.k.external"
-	defaultVersion := defaults.Version
-
-	return maven.Dependency{
-		GroupID:    defaultGroupID,
-		ArtifactID: defaultArtifactID,
-		Type:       ext,
-		Version:    defaultVersion,
-	}, nil
-}
-
-func isPom(path string) bool {
-	return strings.HasSuffix(path, ".pom") || strings.HasSuffix(path, "pom.xml")
-}
-
-func isJar(path string) bool {
-	return strings.HasSuffix(path, ".jar")
-}
-
-func getFileRelativePathAndExtension(path string, dirName string) (string, string, error) {
-	extension := filepath.Ext(path)
-	name, err := filepath.Rel(dirName, path)
-	if err != nil {
-		return "", "", err
-	}
-	return name[0 : len(name)-len(extension)], extension[1:], nil
-}
-
-func getDirName(path string) (string, error) {
-	parentDir := path
-	fileInfo, err := os.Stat(path)
-	if err != nil {
-		return "", err
-	}
-	if !fileInfo.IsDir() {
-		parentDir = filepath.Dir(parentDir)
-	}
-	return parentDir, nil
-}
