@@ -20,14 +20,9 @@ package cmd
 import (
 	"context"
 	"fmt"
-	"io"
-	"net/http"
-	"net/url"
 	"os"
-	"path/filepath"
 	"reflect"
 	"strings"
-	"time"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/client"
@@ -81,7 +76,11 @@ func keyValueProps(value string) (*properties.Properties, error) {
 	return properties.Load([]byte(value), properties.UTF8)
 }
 
+// Deprecated: won't be supported in future releases.
 func loadPropertiesFromSecret(ctx context.Context, c client.Client, ns string, name string) (*properties.Properties, error) {
+	if c == nil {
+		return nil, fmt.Errorf("cannot inspect Secrets in offline mode")
+	}
 	secret := kubernetes.LookupSecret(ctx, c, ns, name)
 	if secret == nil {
 		return nil, fmt.Errorf("%s secret not found in %s namespace, make sure to provide it before the Integration can run", name, ns)
@@ -93,7 +92,11 @@ func loadPropertiesFromSecret(ctx context.Context, c client.Client, ns string, n
 		})
 }
 
+// Deprecated: won't be supported in future releases.
 func loadPropertiesFromConfigMap(ctx context.Context, c client.Client, ns string, name string) (*properties.Properties, error) {
+	if c == nil {
+		return nil, fmt.Errorf("cannot inspect Configmaps in offline mode")
+	}
 	cm := kubernetes.LookupConfigmap(ctx, c, ns, name)
 	if cm == nil {
 		return nil, fmt.Errorf("%s configmap not found in %s namespace, make sure to provide it before the Integration can run", name, ns)
@@ -103,6 +106,7 @@ func loadPropertiesFromConfigMap(ctx context.Context, c client.Client, ns string
 		func(v reflect.Value) (*properties.Properties, error) { return keyValueProps(v.String()) })
 }
 
+// Deprecated: func supporting other deprecated funcs.
 func fromMapToProperties(data interface{}, toString func(reflect.Value) string, loadProperties func(reflect.Value) (*properties.Properties, error)) (*properties.Properties, error) {
 	result := properties.NewProperties()
 	m := reflect.ValueOf(data)
@@ -123,39 +127,6 @@ func fromMapToProperties(data interface{}, toString func(reflect.Value) string,
 	return result, nil
 }
 
-// downloadDependency downloads the file located at the given URL into a temporary folder and returns the local path to the generated temporary file.
-func downloadDependency(ctx context.Context, url url.URL) (string, error) {
-	tctx, cancel := context.WithTimeout(ctx, 3*time.Second)
-	defer cancel()
-
-	req, err := http.NewRequestWithContext(tctx, http.MethodGet, url.String(), nil)
-	if err != nil {
-		return "", err
-	}
-	res, err := http.DefaultClient.Do(req)
-	if err != nil {
-		return "", err
-	}
-	defer res.Body.Close()
-	base := filepath.Base(url.Path)
-	if base == "." || base == "/" || filepath.Ext(base) == "" {
-		base = filepath.Base(url.String())
-		if base == "." || base == "/" {
-			base = "tmp"
-		}
-	}
-	out, err := os.CreateTemp("", fmt.Sprintf("*.%s", base))
-	if err != nil {
-		return "", err
-	}
-	defer out.Close()
-	_, err = io.Copy(out, res.Body)
-	if err != nil {
-		return "", err
-	}
-	return out.Name(), nil
-}
-
 func validatePropertyFiles(propertyFiles []string) error {
 	for _, fileName := range propertyFiles {
 		if err := validatePropertyFile(fileName); err != nil {
