@@ -45,11 +45,12 @@ func TestBuilderTraitNotAppliedBecauseOfNilKit(t *testing.T) {
 		e.IntegrationKit = nil
 
 		t.Run(string(e.Platform.Status.Cluster), func(t *testing.T) {
-			conditions, err := NewBuilderTestCatalog().apply(e)
+			trait, _ := newBuilderTrait().(*builderTrait)
 
+			configure, conditions, err := trait.Configure(e)
+			assert.False(t, configure)
+			assert.Empty(t, conditions)
 			require.NoError(t, err)
-			assert.NotEmpty(t, conditions)
-			assert.NotEmpty(t, e.ExecutedTraits)
 			assert.Nil(t, e.GetTrait("builder"))
 			assert.Empty(t, e.Pipeline)
 		})
@@ -66,10 +67,11 @@ func TestBuilderTraitNotAppliedBecauseOfNilPhase(t *testing.T) {
 		e.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseInitialization
 
 		t.Run(string(e.Platform.Status.Cluster), func(t *testing.T) {
-			conditions, err := NewBuilderTestCatalog().apply(e)
+			conditions, traits, err := NewBuilderTestCatalog().apply(e)
 
 			require.NoError(t, err)
 			assert.NotEmpty(t, conditions)
+			assert.Empty(t, traits)
 			assert.NotEmpty(t, e.ExecutedTraits)
 			assert.Nil(t, e.GetTrait("builder"))
 			assert.Empty(t, e.Pipeline)
@@ -79,9 +81,10 @@ func TestBuilderTraitNotAppliedBecauseOfNilPhase(t *testing.T) {
 
 func TestS2IBuilderTrait(t *testing.T) {
 	env := createBuilderTestEnv(v1.IntegrationPlatformClusterOpenShift, v1.IntegrationPlatformBuildPublishStrategyS2I, v1.BuildStrategyRoutine)
-	conditions, err := NewBuilderTestCatalog().apply(env)
+	conditions, traits, err := NewBuilderTestCatalog().apply(env)
 
 	require.NoError(t, err)
+	assert.Empty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, env.ExecutedTraits)
 	assert.NotNil(t, env.GetTrait("builder"))
@@ -96,9 +99,10 @@ func TestS2IBuilderTrait(t *testing.T) {
 
 func TestJibBuilderTrait(t *testing.T) {
 	env := createBuilderTestEnv(v1.IntegrationPlatformClusterOpenShift, v1.IntegrationPlatformBuildPublishStrategyJib, v1.BuildStrategyRoutine)
-	conditions, err := NewBuilderTestCatalog().apply(env)
+	conditions, traits, err := NewBuilderTestCatalog().apply(env)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, env.ExecutedTraits)
 	assert.NotNil(t, env.GetTrait("builder"))
@@ -145,11 +149,10 @@ func createBuilderTestEnv(cluster v1.IntegrationPlatformCluster, strategy v1.Int
 			Spec: v1.IntegrationPlatformSpec{
 				Cluster: cluster,
 				Build: v1.IntegrationPlatformBuildSpec{
-					PublishStrategy:        strategy,
-					Registry:               v1.RegistrySpec{Address: "registry"},
-					RuntimeVersion:         defaults.DefaultRuntimeVersion,
-					RuntimeProvider:        v1.RuntimeProviderQuarkus,
-					PublishStrategyOptions: map[string]string{},
+					PublishStrategy: strategy,
+					Registry:        v1.RegistrySpec{Address: "registry"},
+					RuntimeVersion:  defaults.DefaultRuntimeVersion,
+					RuntimeProvider: v1.RuntimeProviderQuarkus,
 					BuildConfiguration: v1.BuildConfiguration{
 						Strategy: buildStrategy,
 					},
@@ -386,7 +389,7 @@ func TestBuilderCustomTasksConfiguration(t *testing.T) {
 	builderTrait.TasksRequestMemory = append(builderTrait.TasksRequestMemory, "package:8Gi")
 	builderTrait.TasksLimitMemory = append(builderTrait.TasksLimitMemory, "spectrum:4Gi")
 
-	tasksConf, err := builderTrait.parseTasksConf()
+	tasksConf, err := builderTrait.parseTasksConf(&v1.BuildConfiguration{})
 
 	require.NoError(t, err)
 	assert.Equal(t, 4, len(tasksConf))
@@ -400,7 +403,7 @@ func TestBuilderCustomTasksConfigurationError(t *testing.T) {
 	builderTrait := createNominalBuilderTraitTest()
 	builderTrait.TasksLimitCPU = append(builderTrait.TasksLimitCPU, "syntax error")
 
-	_, err := builderTrait.parseTasksConf()
+	_, err := builderTrait.parseTasksConf(&v1.BuildConfiguration{})
 
 	require.Error(t, err)
 	assert.Equal(t, "could not parse syntax error, expected format <task-name>:<task-resource>", err.Error())
@@ -591,6 +594,20 @@ func TestBuilderTasksFilterAndReorderCustomTasks(t *testing.T) {
 	assert.Equal(t, []string{"builder", "my-custom-task", "package", "my-custom-publish"}, pipelineTasks)
 }
 
+func TestBuilderTasksNodeSelectorPlatformBuildStrategyPod(t *testing.T) {
+	env := createBuilderTestEnv(v1.IntegrationPlatformClusterKubernetes, v1.IntegrationPlatformBuildPublishStrategyJib, v1.BuildStrategyPod)
+	builderTrait := createNominalBuilderTraitTest()
+	builderTrait.NodeSelector = map[string]string{
+		"kubernetes.io/arch": "amd64",
+	}
+
+	err := builderTrait.Apply(env)
+	require.NoError(t, err)
+	builderTask := getBuilderTask(env.Pipeline)
+	assert.NotNil(t, builderTask)
+	assert.Equal(t, map[string]string{"kubernetes.io/arch": "amd64"}, builderTask.Configuration.NodeSelector)
+}
+
 func findCustomTaskByName(tasks []v1.Task, name string) v1.Task {
 	for _, t := range tasks {
 		if t.Custom != nil && t.Custom.Name == name {
