@@ -26,13 +26,13 @@ import (
 	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/metadata"
 	"github.com/apache/camel-k/v2/pkg/util"
-	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/source"
 	"github.com/apache/camel-k/v2/pkg/util/uri"
 )
 
@@ -45,6 +45,8 @@ const (
 	defaultCronBackoffLimit            = int32(2)
 	genericCronComponent               = "cron"
 	genericCronComponentFallbackScheme = "quartz"
+
+	overriddenFromURI = "timer:camel-k-overridden-cron?delay=0&period=1&repeatCount=1"
 )
 
 type cronTrait struct {
@@ -83,26 +85,14 @@ func (t *cronTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	if e.Integration == nil {
 		return false, nil, nil
 	}
-	if !pointer.BoolDeref(t.Enabled, true) {
+	if !ptr.Deref(t.Enabled, true) {
 		return false, NewIntegrationConditionUserDisabled("Cron"), nil
 	}
 	if !e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases() {
 		return false, nil, nil
 	}
-	if e.CamelCatalog == nil {
-		return false, NewIntegrationConditionPlatformDisabledCatalogMissing(), nil
-	}
-	if _, ok := e.CamelCatalog.Runtime.Capabilities[v1.CapabilityCron]; !ok {
-		return false, NewIntegrationCondition(
-			"Cron",
-			v1.IntegrationConditionCronJobAvailable,
-			corev1.ConditionFalse,
-			v1.IntegrationConditionCronJobNotAvailableReason,
-			"the runtime provider %s does not declare 'cron' capability",
-		), nil
-	}
 
-	if pointer.BoolDeref(t.Auto, true) {
+	if ptr.Deref(t.Auto, true) {
 		err := t.autoConfigure(e)
 		if err != nil {
 			return false,
@@ -118,7 +108,7 @@ func (t *cronTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	}
 
 	// Fallback strategy can be implemented in any other controller
-	if pointer.BoolDeref(t.Fallback, false) {
+	if ptr.Deref(t.Fallback, false) {
 		var condition *TraitCondition
 		if e.IntegrationInPhase(v1.IntegrationPhaseDeploying) {
 			condition = NewIntegrationCondition(
@@ -147,7 +137,11 @@ func (t *cronTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 		return false, nil, nil
 	}
 
-	return t.Schedule != "", nil, nil
+	if t.Schedule != "" {
+		t.Enabled = ptr.To(true)
+	}
+
+	return ptr.Deref(t.Enabled, false), nil, nil
 }
 
 func (t *cronTrait) autoConfigure(e *Environment) error {
@@ -168,10 +162,6 @@ func (t *cronTrait) autoConfigure(e *Environment) error {
 		t.Components = strings.Join(configuredComponents, ",")
 	}
 
-	if t.ConcurrencyPolicy == "" {
-		t.ConcurrencyPolicy = string(batchv1.ForbidConcurrent)
-	}
-
 	if (t.Schedule == "" && t.Components == "") && t.Fallback == nil {
 		// If there's at least a `cron` endpoint, add a fallback implementation
 		fromURIs, err := t.getSourcesFromURIs(e)
@@ -180,7 +170,7 @@ func (t *cronTrait) autoConfigure(e *Environment) error {
 		}
 		for _, fromURI := range fromURIs {
 			if uri.GetComponent(fromURI) == genericCronComponent {
-				t.Fallback = pointer.Bool(true)
+				t.Fallback = ptr.To(true)
 				break
 			}
 		}
@@ -190,27 +180,36 @@ func (t *cronTrait) autoConfigure(e *Environment) error {
 }
 
 func (t *cronTrait) Apply(e *Environment) error {
+	//nolint: nestif
 	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
 		util.StringSliceUniqueAdd(&e.Integration.Status.Capabilities, v1.CapabilityCron)
-
-		if pointer.BoolDeref(t.Fallback, false) {
+		if ptr.Deref(t.Fallback, false) {
 			fallbackArtifact := e.CamelCatalog.GetArtifactByScheme(genericCronComponentFallbackScheme)
 			if fallbackArtifact == nil {
 				return fmt.Errorf("no fallback artifact for scheme %q has been found in camel catalog", genericCronComponentFallbackScheme)
 			}
 			util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, fallbackArtifact.GetDependencyID())
 			util.StringSliceUniqueConcat(&e.Integration.Status.Dependencies, fallbackArtifact.GetConsumerDependencyIDs(genericCronComponentFallbackScheme))
+
+			return nil
 		}
+		// Will change the "from" URI in order to execute the task just once
+		if err := t.changeSourcesCronURI(e); err != nil {
+			return err
+		}
+		cronComponentArtifact := e.CamelCatalog.GetArtifactByScheme("timer")
+		if cronComponentArtifact == nil {
+			return fmt.Errorf("no timer artifact has been found in camel catalog")
+		}
+		util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, cronComponentArtifact.GetDependencyID())
 	}
 
-	if !pointer.BoolDeref(t.Fallback, false) && e.IntegrationInRunningPhases() {
+	if e.IntegrationInRunningPhases() && !ptr.Deref(t.Fallback, false) {
 		if e.ApplicationProperties == nil {
 			e.ApplicationProperties = make(map[string]string)
 		}
-
-		e.ApplicationProperties["camel.main.duration-max-idle-seconds"] = "5"
-		e.ApplicationProperties["loader.interceptor.cron.overridable-components"] = t.Components
-		e.Interceptors = append(e.Interceptors, "cron")
+		// Will instruct the context to stop as soon as the first message is done
+		e.ApplicationProperties["camel.main.durationMaxMessages"] = "1"
 
 		cronJob := t.getCronJobFor(e)
 		e.Resources.Add(cronJob)
@@ -219,7 +218,12 @@ func (t *cronTrait) Apply(e *Environment) error {
 			v1.IntegrationConditionCronJobAvailable,
 			corev1.ConditionTrue,
 			v1.IntegrationConditionCronJobAvailableReason,
-			fmt.Sprintf("CronJob name is %s", cronJob.Name))
+			fmt.Sprintf(
+				"CronJob name is %s. Notice that the routes \"from\" parameter was changed to "+
+					"\"%s\" in order to be able to trigger the Camel application as a CronJob.",
+				cronJob.Name,
+				overriddenFromURI,
+			))
 	}
 
 	return nil
@@ -258,7 +262,7 @@ func (t *cronTrait) getCronJobFor(e *Environment) *batchv1.CronJob {
 		Spec: batchv1.CronJobSpec{
 			Schedule:                t.Schedule,
 			TimeZone:                t.TimeZone,
-			ConcurrencyPolicy:       batchv1.ConcurrencyPolicy(t.ConcurrencyPolicy),
+			ConcurrencyPolicy:       t.getConcurrentPolicy(),
 			StartingDeadlineSeconds: t.StartingDeadlineSeconds,
 			JobTemplate: batchv1.JobTemplateSpec{
 				Spec: batchv1.JobSpec{
@@ -287,13 +291,13 @@ func (t *cronTrait) getCronJobFor(e *Environment) *batchv1.CronJob {
 // SelectControllerStrategy can be used to check if a CronJob can be generated given the integration and trait settings.
 func (t *cronTrait) SelectControllerStrategy(e *Environment) (*ControllerStrategy, error) {
 	cronStrategy := ControllerStrategyCronJob
-	if pointer.BoolDeref(t.Fallback, false) {
+	if ptr.Deref(t.Fallback, false) {
 		return nil, nil
 	}
 	if t.Schedule != "" {
 		return &cronStrategy, nil
 	}
-	if pointer.BoolDeref(t.Auto, true) {
+	if ptr.Deref(t.Auto, true) {
 		globalCron, err := t.getGlobalCron(e)
 		if err == nil && globalCron != nil {
 			return &cronStrategy, nil
@@ -325,9 +329,6 @@ func (c *cronInfo) withSchedule(schedule string) *cronInfo {
 }
 
 func (t *cronTrait) getGlobalCron(e *Environment) (*cronInfo, error) {
-	if e.CamelCatalog == nil {
-		return nil, nil
-	}
 	fromURIs, err := t.getSourcesFromURIs(e)
 	if err != nil {
 		return nil, err
@@ -356,17 +357,24 @@ func (t *cronTrait) getGlobalCron(e *Environment) (*cronInfo, error) {
 }
 
 func (t *cronTrait) getSourcesFromURIs(e *Environment) ([]string, error) {
-	var sources []v1.SourceSpec
-	var err error
-	if sources, err = kubernetes.ResolveIntegrationSources(e.Ctx, t.Client, e.Integration, e.Resources); err != nil {
-		return nil, err
-	}
-	meta, err := metadata.ExtractAll(e.CamelCatalog, sources)
+	var fromUris []string
+	_, err := e.ConsumeMeta(true, func(meta metadata.IntegrationMetadata) bool {
+		fromUris = meta.FromURIs
+		return true
+	})
 	if err != nil {
 		return nil, err
 	}
 
-	return meta.FromURIs, nil
+	return fromUris, nil
+}
+
+func (t *cronTrait) getConcurrentPolicy() batchv1.ConcurrencyPolicy {
+	if t.ConcurrencyPolicy == "" {
+		return batchv1.ForbidConcurrent
+	}
+
+	return batchv1.ConcurrencyPolicy(t.ConcurrencyPolicy)
 }
 
 func getCronForURIs(camelURIs []string) *cronInfo {
@@ -502,3 +510,20 @@ func checkedStringToUint64(str string) uint64 {
 	}
 	return res
 }
+
+// changeSourcesCronURI is in charge to change the value of the from route with a component that executes
+// the workload just once.
+func (t *cronTrait) changeSourcesCronURI(e *Environment) error {
+	for _, src := range e.Integration.AllSources() {
+		dslInspector := source.InspectorForLanguage(e.CamelCatalog, src.InferLanguage())
+		replaced, err := dslInspector.ReplaceFromURI(&src, overriddenFromURI)
+		if replaced {
+			// replace generated source
+			e.Integration.Status.AddOrReplaceGeneratedSources(src)
+		} else if err != nil {
+			return fmt.Errorf("wasn't able to replace cron uri trigger in source %s", src.Name)
+		}
+	}
+
+	return nil
+}
