@@ -26,12 +26,15 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	networkingv1 "k8s.io/api/networking/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 )
 
 const (
 	ingressTraitID    = "ingress"
 	ingressTraitOrder = 2400
+
+	defaultPath           = "/"
+	defaultPathTypePrefix = networkingv1.PathTypePrefix
 )
 
 type ingressTrait struct {
@@ -42,14 +45,6 @@ type ingressTrait struct {
 func newIngressTrait() Trait {
 	return &ingressTrait{
 		BaseTrait: NewBaseTrait(ingressTraitID, ingressTraitOrder),
-		IngressTrait: traitv1.IngressTrait{
-			Annotations:   map[string]string{},
-			Host:          "",
-			Path:          "/",
-			PathType:      ptrFrom(networkingv1.PathTypePrefix),
-			TLSHosts:      []string{},
-			TLSSecretName: "",
-		},
 	}
 }
 
@@ -65,7 +60,7 @@ func (t *ingressTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 	if !e.IntegrationInRunningPhases() {
 		return false, nil, nil
 	}
-	if !pointer.BoolDeref(t.Enabled, true) {
+	if !ptr.Deref(t.Enabled, true) {
 		return false, NewIntegrationCondition(
 			"Ingress",
 			v1.IntegrationConditionExposureAvailable,
@@ -75,7 +70,7 @@ func (t *ingressTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 		), nil
 	}
 
-	if pointer.BoolDeref(t.Auto, true) {
+	if ptr.Deref(t.Auto, true) {
 		if e.Resources.GetUserServiceForIntegration(e.Integration) == nil {
 			return false, nil, nil
 		}
@@ -87,7 +82,7 @@ func (t *ingressTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 func (t *ingressTrait) Apply(e *Environment) error {
 	service := e.Resources.GetUserServiceForIntegration(e.Integration)
 	if service == nil {
-		return errors.New("cannot Apply ingress trait: no target service")
+		return errors.New("cannot apply ingress trait: no target service")
 	}
 
 	ingress := networkingv1.Ingress{
@@ -108,8 +103,8 @@ func (t *ingressTrait) Apply(e *Environment) error {
 						HTTP: &networkingv1.HTTPIngressRuleValue{
 							Paths: []networkingv1.HTTPIngressPath{
 								{
-									Path:     t.Path,
-									PathType: t.PathType,
+									Path:     t.getPath(),
+									PathType: t.getPathType(),
 									Backend: networkingv1.IngressBackend{
 										Service: &networkingv1.IngressServiceBackend{
 											Name: service.Name,
@@ -126,6 +121,9 @@ func (t *ingressTrait) Apply(e *Environment) error {
 			},
 		},
 	}
+	if t.IngressClassName != "" {
+		ingress.Spec.IngressClassName = &t.IngressClassName
+	}
 
 	if len(t.TLSHosts) > 0 && t.TLSSecretName != "" {
 		ingress.Spec.TLS = []networkingv1.IngressTLS{
@@ -149,3 +147,19 @@ func (t *ingressTrait) Apply(e *Environment) error {
 
 	return nil
 }
+
+func (t *ingressTrait) getPath() string {
+	if t.Path == "" {
+		return defaultPath
+	}
+
+	return t.Path
+}
+
+func (t *ingressTrait) getPathType() *networkingv1.PathType {
+	if t.PathType == nil {
+		return ptr.To(defaultPathTypePrefix)
+	}
+
+	return t.PathType
+}
