@@ -23,7 +23,7 @@ import (
 	"strings"
 
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
@@ -45,14 +45,11 @@ type jolokiaTrait struct {
 func newJolokiaTrait() Trait {
 	return &jolokiaTrait{
 		BaseTrait: NewBaseTrait(jolokiaTraitID, jolokiaTraitOrder),
-		JolokiaTrait: traitv1.JolokiaTrait{
-			Port: defaultJolokiaPort,
-		},
 	}
 }
 
 func (t *jolokiaTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, false) {
+	if e.Integration == nil || !ptr.Deref(t.Enabled, false) {
 		return false, nil, nil
 	}
 
@@ -107,7 +104,7 @@ func (t *jolokiaTrait) Apply(e *Environment) error {
 	t.addToJolokiaOptions(options, "extendedClientCheck", t.ExtendedClientCheck)
 	t.addToJolokiaOptions(options, "host", t.Host)
 	t.addToJolokiaOptions(options, "password", t.Password)
-	t.addToJolokiaOptions(options, "port", t.Port)
+	t.addToJolokiaOptions(options, "port", t.getPort())
 	t.addToJolokiaOptions(options, "protocol", t.Protocol)
 	t.addToJolokiaOptions(options, "user", t.User)
 	t.addToJolokiaOptions(options, "useSslClientAuthentication", t.UseSslClientAuthentication)
@@ -131,7 +128,7 @@ func (t *jolokiaTrait) Apply(e *Environment) error {
 
 	containerPort := corev1.ContainerPort{
 		Name:          "jolokia",
-		ContainerPort: int32(t.Port),
+		ContainerPort: int32(t.getPort()),
 		Protocol:      corev1.ProtocolTCP,
 	}
 
@@ -147,6 +144,14 @@ func (t *jolokiaTrait) Apply(e *Environment) error {
 	return nil
 }
 
+func (t *jolokiaTrait) getPort() int {
+	if t.Port == 0 {
+		return defaultJolokiaPort
+	}
+
+	return t.Port
+}
+
 func (t *jolokiaTrait) setDefaultJolokiaOption(options map[string]string, option interface{}, key string, value interface{}) {
 	// Do not override existing option
 	if _, ok := options[key]; ok {
