@@ -20,10 +20,10 @@ package trait
 import (
 	"fmt"
 	"path/filepath"
-	"strings"
 	"testing"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/test"
@@ -32,7 +32,7 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 )
 
@@ -74,7 +74,7 @@ func TestConfigureJvmTraitInWrongIntegrationKitPhaseDoesNotSucceed(t *testing.T)
 
 func TestConfigureJvmTraitInWrongJvmDisabled(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
-	trait.Enabled = pointer.Bool(false)
+	trait.Enabled = ptr.To(false)
 
 	expectedCondition := NewIntegrationCondition(
 		"JVM",
@@ -90,9 +90,11 @@ func TestConfigureJvmTraitInWrongJvmDisabled(t *testing.T) {
 	assert.Equal(t, expectedCondition, condition)
 }
 
-func TestConfigureJvmTraitExecutableSourcelessContainer(t *testing.T) {
+func TestConfigureJvmTraitExecutableSelfManagedBuildContainer(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
-	environment.IntegrationKit.Labels[v1.IntegrationKitTypeLabel] = v1.IntegrationKitTypeSynthetic
+	environment.Integration.Spec.Traits.Container = &traitv1.ContainerTrait{
+		Image: "my-image",
+	}
 
 	configured, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
@@ -103,9 +105,11 @@ func TestConfigureJvmTraitExecutableSourcelessContainer(t *testing.T) {
 	)
 }
 
-func TestConfigureJvmTraitExecutableSourcelessContainerWithJar(t *testing.T) {
+func TestConfigureJvmTraitExecutableSelfManagedBuildContainerWithJar(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
-	environment.IntegrationKit.Labels[v1.IntegrationKitTypeLabel] = v1.IntegrationKitTypeSynthetic
+	environment.Integration.Spec.Traits.Container = &traitv1.ContainerTrait{
+		Image: "my-image",
+	}
 	trait.Jar = "my-path/to/my-app.jar"
 
 	d := appsv1.Deployment{
@@ -138,9 +142,11 @@ func TestConfigureJvmTraitExecutableSourcelessContainerWithJar(t *testing.T) {
 	}, d.Spec.Template.Spec.Containers[0].Args)
 }
 
-func TestConfigureJvmTraitExecutableSourcelessContainerWithJarAndOptions(t *testing.T) {
+func TestConfigureJvmTraitExecutableSelfManagedBuildContainerWithJarAndOptions(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
-	environment.IntegrationKit.Labels[v1.IntegrationKitTypeLabel] = v1.IntegrationKitTypeSynthetic
+	environment.Integration.Spec.Traits.Container = &traitv1.ContainerTrait{
+		Image: "my-image",
+	}
 	trait.Jar = "my-path/to/my-app.jar"
 	// Add some additional JVM configurations
 	trait.Classpath = "deps/a.jar:deps/b.jar"
@@ -254,8 +260,10 @@ func TestConfigureJvmTraitWithJarAndConfigs(t *testing.T) {
 }
 
 func TestConfigureJvmTraitInWrongIntegrationKitPhaseExternal(t *testing.T) {
-	trait, environment := createNominalJvmTest(v1.IntegrationKitTypeSynthetic)
-
+	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
+	environment.Integration.Spec.Traits.Container = &traitv1.ContainerTrait{
+		Image: "my-image",
+	}
 	expectedCondition := NewIntegrationCondition(
 		"JVM",
 		v1.IntegrationConditionTraitInfo,
@@ -346,8 +354,8 @@ func TestApplyJvmTraitWithKnativeResource(t *testing.T) {
 
 func TestApplyJvmTraitWithDebugEnabled(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
-	trait.Debug = pointer.Bool(true)
-	trait.DebugSuspend = pointer.Bool(true)
+	trait.Debug = ptr.To(true)
+	trait.DebugSuspend = ptr.To(true)
 
 	d := appsv1.Deployment{
 		Spec: appsv1.DeploymentSpec{
@@ -485,7 +493,7 @@ func TestApplyJvmTraitWithClasspathAndExistingContainerCPArg(t *testing.T) {
 		"-cp",
 		"my-precious-lib.jar",
 		"-cp",
-		fmt.Sprintf("my-precious-lib.jar:./resources:%s:%s:%s:%s:%s:dependencies/*",
+		fmt.Sprintf("./resources:%s:%s:%s:%s:%s:dependencies/*:my-precious-lib.jar",
 			rdMountPath, cmrMountPath, scrMountPath,
 			"/path/to/another/dep.jar", "/path/to/my-dep.jar"),
 		"io.quarkus.bootstrap.runner.QuarkusEntryPoint",
@@ -494,12 +502,13 @@ func TestApplyJvmTraitWithClasspathAndExistingContainerCPArg(t *testing.T) {
 
 func TestApplyJvmTraitKitMissing(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
-	environment.IntegrationKit = nil
-
+	environment.Integration.Spec.Traits.Container = &traitv1.ContainerTrait{
+		Image: "my-image",
+	}
 	err := trait.Apply(environment)
 
 	require.Error(t, err)
-	assert.True(t, strings.HasPrefix(err.Error(), "unable to find integration kit"))
+	assert.Equal(t, "unable to find a container for my-it Integration", err.Error())
 }
 
 func TestApplyJvmTraitContainerResourceArgs(t *testing.T) {
@@ -585,13 +594,17 @@ func createNominalJvmTest(kitType string) (*jvmTrait, *Environment) {
 	catalog, _ := camel.DefaultCatalog()
 	client, _ := test.NewFakeClient()
 	trait, _ := newJvmTrait().(*jvmTrait)
-	trait.PrintCommand = pointer.Bool(false)
+	trait.PrintCommand = ptr.To(false)
 	trait.Client = client
 
 	environment := &Environment{
 		Catalog:      NewCatalog(nil),
 		CamelCatalog: catalog,
 		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "kit-namespace",
+				Name:      "my-it",
+			},
 			Status: v1.IntegrationStatus{
 				Phase: v1.IntegrationPhaseDeploying,
 			},
