@@ -22,6 +22,7 @@ import (
 	"testing"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
@@ -31,7 +32,7 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 )
 
 func TestConfigurationNoKameletsUsed(t *testing.T) {
@@ -54,6 +55,7 @@ func TestConfigurationWithKamelets(t *testing.T) {
     uri: kamelet:c1
     steps:
     - to: kamelet:c2
+    - to: kamelet:c3?kameletVersion=v1
     - to: telegram:bots
     - to: kamelet://c0?prop=x
     - to: kamelet://complex-.-.-1a?prop=x&prop2
@@ -66,17 +68,8 @@ func TestConfigurationWithKamelets(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"c0", "c1", "c2", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys())
-	assert.Equal(t, []configurationKey{
-		newConfigurationKey("c0", ""),
-		newConfigurationKey("c1", ""),
-		newConfigurationKey("c2", ""),
-		newConfigurationKey("complex-.-.-1a", ""),
-		newConfigurationKey("complex-.-.-1b", ""),
-		newConfigurationKey("complex-.-.-1b", "a"),
-		newConfigurationKey("complex-.-.-1c", ""),
-		newConfigurationKey("complex-.-.-1c", "b"),
-	}, trait.getConfigurationKeys())
+	assert.Equal(t, []string{"c0", "c1", "c2", "c3", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"c0", "c1", "c2", "c3-v1", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys(true))
 }
 
 func TestKameletLookup(t *testing.T) {
@@ -91,14 +84,16 @@ func TestKameletLookup(t *testing.T) {
 			Name:      "timer",
 		},
 		Spec: v1.KameletSpec{
-			Template: templateOrFail(map[string]interface{}{
-				"from": map[string]interface{}{
-					"uri": "timer:tick",
+			KameletSpecBase: v1.KameletSpecBase{
+				Template: templateOrFail(map[string]interface{}{
+					"from": map[string]interface{}{
+						"uri": "timer:tick",
+					},
+				}),
+				Dependencies: []string{
+					"camel:timer",
+					"camel:log",
 				},
-			}),
-			Dependencies: []string{
-				"camel:timer",
-				"camel:log",
 			},
 		},
 	})
@@ -106,7 +101,7 @@ func TestKameletLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -135,18 +130,20 @@ func TestKameletSecondarySourcesLookup(t *testing.T) {
 			Name:      "timer",
 		},
 		Spec: v1.KameletSpec{
-			Template: templateOrFail(map[string]interface{}{
-				"from": map[string]interface{}{
-					"uri": "timer:tick",
-				},
-			}),
-			Sources: []v1.SourceSpec{
-				{
-					DataSpec: v1.DataSpec{
-						Name:    "support.groovy",
-						Content: "from('xxx:xxx').('to:log:info')",
+			KameletSpecBase: v1.KameletSpecBase{
+				Template: templateOrFail(map[string]interface{}{
+					"from": map[string]interface{}{
+						"uri": "timer:tick",
+					},
+				}),
+				Sources: []v1.SourceSpec{
+					{
+						DataSpec: v1.DataSpec{
+							Name:    "support.groovy",
+							Content: "from('xxx:xxx').('to:log:info')",
+						},
+						Language: v1.LanguageGroovy,
 					},
-					Language: v1.LanguageGroovy,
 				},
 			},
 		},
@@ -155,7 +152,7 @@ func TestKameletSecondarySourcesLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -191,13 +188,15 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 			Name:      "timer",
 		},
 		Spec: v1.KameletSpec{
-			Sources: []v1.SourceSpec{
-				{
-					DataSpec: v1.DataSpec{
-						Name:    "mykamelet.groovy",
-						Content: `from("timer").to("log:info")`,
+			KameletSpecBase: v1.KameletSpecBase{
+				Sources: []v1.SourceSpec{
+					{
+						DataSpec: v1.DataSpec{
+							Name:    "mykamelet.groovy",
+							Content: `from("timer").to("log:info")`,
+						},
+						Type: v1.SourceTypeTemplate,
 					},
-					Type: v1.SourceTypeTemplate,
 				},
 			},
 		},
@@ -206,7 +205,7 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -224,33 +223,42 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 func TestMultipleKamelets(t *testing.T) {
 	trait, environment := createKameletsTestEnvironment(`
 - from:
-    uri: kamelet:timer
+    uri: kamelet:timer?kameletVersion=v1
     steps:
     - to: kamelet:logger
-    - to: kamelet:logger
 `, &v1.Kamelet{
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: "test",
 			Name:      "timer",
 		},
 		Spec: v1.KameletSpec{
-			Template: templateOrFail(map[string]interface{}{
-				"from": map[string]interface{}{
-					"uri": "timer:tick",
-				},
-			}),
-			Sources: []v1.SourceSpec{
-				{
-					DataSpec: v1.DataSpec{
-						Name:    "support.groovy",
-						Content: "from('xxx:xxx').('to:log:info')",
+			KameletSpecBase: v1.KameletSpecBase{
+				Template: templateOrFail(map[string]interface{}{
+					"from": map[string]interface{}{
+						"uri": "timer:tick",
 					},
-					Language: v1.LanguageGroovy,
+				}),
+				Dependencies: []string{
+					"camel:timer",
+					"camel:xxx",
 				},
 			},
-			Dependencies: []string{
-				"camel:timer",
-				"camel:xxx",
+			Versions: map[string]v1.KameletSpecBase{
+				"v1": {
+					Sources: []v1.SourceSpec{
+						{
+							DataSpec: v1.DataSpec{
+								Name:    "support.groovy",
+								Content: "from('xxx:xxx').('to:log:info')",
+							},
+							Language: v1.LanguageGroovy,
+						},
+					},
+					Dependencies: []string{
+						"camel:timer",
+						"camel:xxx-2",
+					},
+				},
 			},
 		},
 	}, &v1.Kamelet{
@@ -259,21 +267,43 @@ func TestMultipleKamelets(t *testing.T) {
 			Name:      "logger",
 		},
 		Spec: v1.KameletSpec{
-			Template: templateOrFail(map[string]interface{}{
-				"from": map[string]interface{}{
-					"uri": "tbd:endpoint",
-					"steps": []interface{}{
-						map[string]interface{}{
-							"to": map[string]interface{}{
-								"uri": "log:info",
+			KameletSpecBase: v1.KameletSpecBase{
+				Template: templateOrFail(map[string]interface{}{
+					"from": map[string]interface{}{
+						"uri": "tbd:endpoint",
+						"steps": []interface{}{
+							map[string]interface{}{
+								"to": map[string]interface{}{
+									"uri": "log:info?option=main",
+								},
 							},
 						},
 					},
+				}),
+				Dependencies: []string{
+					"camel:log",
+					"camel:tbd",
+				},
+			},
+			Versions: map[string]v1.KameletSpecBase{
+				"v2": {
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "tbd:endpoint",
+							"steps": []interface{}{
+								map[string]interface{}{
+									"to": map[string]interface{}{
+										"uri": "log:info?option=version2",
+									},
+								},
+							},
+						},
+					}),
+					Dependencies: []string{
+						"camel:log",
+						"camel:tbd-2",
+					},
 				},
-			}),
-			Dependencies: []string{
-				"camel:log",
-				"camel:tbd",
 			},
 		},
 	})
@@ -281,39 +311,48 @@ func TestMultipleKamelets(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"logger", "timer"}, trait.getKameletKeys())
+	assert.Equal(t, "logger,timer?kameletVersion=v1", trait.List)
+	assert.Equal(t, []string{"logger", "timer"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"logger", "timer-v1"}, trait.getKameletKeys(true))
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
 
-	cmFlow := environment.Resources.GetConfigMap(func(c *corev1.ConfigMap) bool { return c.Name == "it-kamelet-timer-template" })
-	assert.NotNil(t, cmFlow)
-	cmRes := environment.Resources.GetConfigMap(func(c *corev1.ConfigMap) bool { return c.Name == "it-kamelet-timer-000" })
-	assert.NotNil(t, cmRes)
-	cmFlow2 := environment.Resources.GetConfigMap(func(c *corev1.ConfigMap) bool { return c.Name == "it-kamelet-logger-template" })
-	assert.NotNil(t, cmFlow2)
+	cmFlowTimerSource := environment.Resources.GetConfigMap(func(c *corev1.ConfigMap) bool { return c.Name == "it-kamelet-timer-000" })
+	assert.NotNil(t, cmFlowTimerSource)
+	assert.Contains(t, cmFlowTimerSource.Data[contentKey], "from('xxx:xxx').('to:log:info')")
+	cmFlowMissing := environment.Resources.GetConfigMap(func(c *corev1.ConfigMap) bool { return c.Name == "it-kamelet-timer-template" })
+	assert.Nil(t, cmFlowMissing)
+	cmFlowLoggerTemplateMain := environment.Resources.GetConfigMap(func(c *corev1.ConfigMap) bool { return c.Name == "it-kamelet-logger-template" })
+	assert.NotNil(t, cmFlowLoggerTemplateMain)
+	assert.Contains(t, cmFlowLoggerTemplateMain.Data[contentKey], "log:info?option=main")
 
-	assert.Len(t, environment.Integration.Status.GeneratedSources, 3)
+	assert.Len(t, environment.Integration.Status.GeneratedSources, 2)
 
-	flowSource2 := environment.Integration.Status.GeneratedSources[0]
-	assert.Equal(t, "logger.yaml", flowSource2.Name)
-	assert.Equal(t, "", string(flowSource2.Type))
-	assert.Equal(t, "it-kamelet-logger-template", flowSource2.ContentRef)
-	assert.Equal(t, "content", flowSource2.ContentKey)
+	expectedFlowSourceTimerV1 := v1.SourceSpec{
+		DataSpec: v1.DataSpec{
+			Name:       "support.groovy",
+			ContentRef: "it-kamelet-timer-000",
+			ContentKey: "content",
+		},
+		Language:    v1.LanguageGroovy,
+		FromKamelet: true,
+	}
 
-	flowSource := environment.Integration.Status.GeneratedSources[1]
-	assert.Equal(t, "timer.yaml", flowSource.Name)
-	assert.Equal(t, "", string(flowSource.Type))
-	assert.Equal(t, "it-kamelet-timer-template", flowSource.ContentRef)
-	assert.Equal(t, "content", flowSource.ContentKey)
+	expectedFlowSinkLoggerMain := v1.SourceSpec{
+		DataSpec: v1.DataSpec{
+			Name:       "logger.yaml",
+			ContentRef: "it-kamelet-logger-template",
+			ContentKey: "content",
+		},
+		Language:    v1.LanguageYaml,
+		FromKamelet: true,
+	}
 
-	supportSource := environment.Integration.Status.GeneratedSources[2]
-	assert.Equal(t, "support.groovy", supportSource.Name)
-	assert.Equal(t, "", string(supportSource.Type))
-	assert.Equal(t, "it-kamelet-timer-000", supportSource.ContentRef)
-	assert.Equal(t, "content", supportSource.ContentKey)
+	assert.Contains(t, environment.Integration.Status.GeneratedSources, expectedFlowSourceTimerV1, expectedFlowSinkLoggerMain)
 
-	assert.Equal(t, []string{"camel:log", "camel:tbd", "camel:timer", "camel:xxx"}, environment.Integration.Status.Dependencies)
+	assert.Contains(t, environment.Integration.Status.Dependencies,
+		"camel:log", "camel:tbd", "camel:timer", "camel:xxx", "camel:xxx-2")
 }
 
 func TestKameletConfigLookup(t *testing.T) {
@@ -328,14 +367,16 @@ func TestKameletConfigLookup(t *testing.T) {
 			Name:      "timer",
 		},
 		Spec: v1.KameletSpec{
-			Template: templateOrFail(map[string]interface{}{
-				"from": map[string]interface{}{
-					"uri": "timer:tick",
+			KameletSpecBase: v1.KameletSpecBase{
+				Template: templateOrFail(map[string]interface{}{
+					"from": map[string]interface{}{
+						"uri": "timer:tick",
+					},
+				}),
+				Dependencies: []string{
+					"camel:timer",
+					"camel:log",
 				},
-			}),
-			Dependencies: []string{
-				"camel:timer",
-				"camel:log",
 			},
 		},
 	}, &corev1.Secret{
@@ -368,13 +409,7 @@ func TestKameletConfigLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
-	assert.Equal(t, []configurationKey{newConfigurationKey("timer", "")}, trait.getConfigurationKeys())
-
-	list, err := trait.listConfigurationSecrets(environment)
-	require.NoError(t, err)
-	assert.Contains(t, list, "my-secret", "my-secret3")
-	assert.NotContains(t, list, "my-secret2")
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
 }
 
 func TestKameletNamedConfigLookup(t *testing.T) {
@@ -389,14 +424,16 @@ func TestKameletNamedConfigLookup(t *testing.T) {
 			Name:      "timer",
 		},
 		Spec: v1.KameletSpec{
-			Template: templateOrFail(map[string]interface{}{
-				"from": map[string]interface{}{
-					"uri": "timer:tick",
+			KameletSpecBase: v1.KameletSpecBase{
+				Template: templateOrFail(map[string]interface{}{
+					"from": map[string]interface{}{
+						"uri": "timer:tick",
+					},
+				}),
+				Dependencies: []string{
+					"camel:timer",
+					"camel:log",
 				},
-			}),
-			Dependencies: []string{
-				"camel:timer",
-				"camel:log",
 			},
 		},
 	}, &corev1.Secret{
@@ -430,16 +467,7 @@ func TestKameletNamedConfigLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
-	assert.Equal(t, []configurationKey{
-		newConfigurationKey("timer", ""),
-		newConfigurationKey("timer", "id2"),
-	}, trait.getConfigurationKeys())
-
-	list, err := trait.listConfigurationSecrets(environment)
-	require.NoError(t, err)
-	assert.Contains(t, list, "my-secret", "my-secret2")
-	assert.NotContains(t, list, "my-secret3")
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
 }
 
 func TestKameletConditionFalse(t *testing.T) {
@@ -457,11 +485,13 @@ func TestKameletConditionFalse(t *testing.T) {
 				Name:      "timer",
 			},
 			Spec: v1.KameletSpec{
-				Template: templateOrFail(map[string]interface{}{
-					"from": map[string]interface{}{
-						"uri": "timer:tick",
-					},
-				}),
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
 			},
 		})
 
@@ -477,7 +507,6 @@ func TestKameletConditionFalse(t *testing.T) {
 	cond := environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable)
 	assert.Equal(t, corev1.ConditionFalse, cond.Status)
 	assert.Equal(t, v1.IntegrationConditionKameletsAvailableReason, cond.Reason)
-	assert.Contains(t, cond.Message, "[timer] found")
 	assert.Contains(t, cond.Message, "kamelets [none] not found")
 }
 
@@ -496,11 +525,13 @@ func TestKameletConditionTrue(t *testing.T) {
 				Name:      "timer",
 			},
 			Spec: v1.KameletSpec{
-				Template: templateOrFail(map[string]interface{}{
-					"from": map[string]interface{}{
-						"uri": "timer:tick",
-					},
-				}),
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
 			},
 		},
 		&v1.Kamelet{
@@ -509,11 +540,13 @@ func TestKameletConditionTrue(t *testing.T) {
 				Name:      "none",
 			},
 			Spec: v1.KameletSpec{
-				Template: templateOrFail(map[string]interface{}{
-					"from": map[string]interface{}{
-						"uri": "timer:tick",
-					},
-				}),
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
 			},
 		})
 
@@ -593,16 +626,18 @@ func TestKameletSyntheticKitConditionTrue(t *testing.T) {
 				Name:      "timer-source",
 			},
 			Spec: v1.KameletSpec{
-				Template: templateOrFail(map[string]interface{}{
-					"from": map[string]interface{}{
-						"uri": "timer:tick",
-					},
-				}),
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
 			},
 		})
 	environment.CamelCatalog = nil
 	environment.Integration.Spec.Sources = nil
-	trait.Auto = pointer.Bool(false)
+	trait.Auto = ptr.To(false)
 	trait.List = "timer-source"
 
 	enabled, condition, err := trait.Configure(environment)
@@ -636,27 +671,80 @@ func TestKameletSyntheticKitAutoConditionFalse(t *testing.T) {
 				Name:      "timer-source",
 			},
 			Spec: v1.KameletSpec{
-				Template: templateOrFail(map[string]interface{}{
-					"from": map[string]interface{}{
-						"uri": "timer:tick",
-					},
-				}),
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
 			},
 		})
-	environment.CamelCatalog = nil
 	environment.Integration.Spec.Sources = nil
 	trait.List = "timer-source"
 
-	// Auto=true by default, so, we will need to skip as
-	// we cannot parse sources
+	// Auto=true by default. The source parsing will be empty as
+	// there are no available sources.
 
 	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
-	assert.False(t, enabled)
-	assert.NotNil(t, condition)
+	assert.True(t, enabled)
+	assert.Nil(t, condition)
 
 	kameletsBundle := environment.Resources.GetConfigMap(func(cm *corev1.ConfigMap) bool {
 		return cm.Labels[kubernetes.ConfigMapTypeLabel] == KameletBundleType
 	})
 	assert.Nil(t, kameletsBundle)
 }
+
+func TestKameletAuto(t *testing.T) {
+	flow := `
+- from:
+    uri: kamelet:timer
+    steps:
+    - to: kamelet:none
+`
+	trait, environment := createKameletsTestEnvironment(
+		flow,
+		&v1.Kamelet{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "test",
+				Name:      "timer",
+			},
+			Spec: v1.KameletSpec{
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
+			},
+		},
+		&v1.Kamelet{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "test",
+				Name:      "none",
+			},
+			Spec: v1.KameletSpec{
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
+			},
+		})
+
+	enabled, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.True(t, enabled)
+	assert.Nil(t, condition)
+
+	err = trait.Apply(environment)
+	require.NoError(t, err)
+	assert.Equal(t, traitv1.KameletsTrait{
+		List: "none,timer",
+	}, trait.KameletsTrait)
+}
