@@ -28,7 +28,7 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
@@ -80,15 +80,20 @@ func TestKnativeService(t *testing.T) {
 						Language: v1.LanguageJavaScript,
 					},
 				},
-				Configuration: []v1.ConfigurationSpec{
-					{Type: "configmap", Value: "my-cm"},
-					{Type: "secret", Value: "my-secret"},
-					{Type: "property", Value: "my-property=my-property-value"},
-				},
 				Traits: v1.Traits{
 					KnativeService: &traitv1.KnativeServiceTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
+						},
+					},
+					Camel: &traitv1.CamelTrait{
+						Properties: []string{
+							"my-property=my-property-value",
+						},
+					},
+					Mount: &traitv1.MountTrait{
+						Configs: []string{
+							"configmap:my-cm", "secret:my-secret",
 						},
 					},
 				},
@@ -119,7 +124,7 @@ func TestKnativeService(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -212,9 +217,9 @@ func TestKnativeServiceWithCustomContainerName(t *testing.T) {
 					},
 					KnativeService: &traitv1.KnativeServiceTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
-						Auto: pointer.Bool(false),
+						Auto: ptr.To(false),
 					},
 					Container: &traitv1.ContainerTrait{
 						Name: "my-container-name",
@@ -247,7 +252,7 @@ func TestKnativeServiceWithCustomContainerName(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -332,7 +337,7 @@ func TestKnativeServiceWithRest(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -400,7 +405,7 @@ func TestKnativeServiceNotApplicable(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -475,7 +480,7 @@ func TestKnativeServiceNoServingAvailable(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -601,7 +606,7 @@ func createKnativeServiceTestEnvironment(t *testing.T, trait *traitv1.KnativeSer
 
 	environment.Platform.ResyncStatusFullConfig()
 
-	_, err = traitCatalog.apply(environment)
+	_, _, err = traitCatalog.apply(environment)
 	require.NoError(t, err)
 
 	return environment
@@ -614,7 +619,7 @@ func TestServiceAnnotation(t *testing.T) {
 	})
 
 	traitsCatalog := environment.Catalog
-	_, err := traitsCatalog.apply(environment)
+	_, _, err := traitsCatalog.apply(environment)
 
 	require.NoError(t, err)
 
@@ -624,5 +629,77 @@ func TestServiceAnnotation(t *testing.T) {
 
 	assert.NotNil(t, service)
 	assert.True(t, reflect.DeepEqual(service.GetAnnotations(), annotationsTest))
+}
 
+func TestKnativeServiceAuto(t *testing.T) {
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	client, _ := test.NewFakeClient()
+	traitCatalog := NewCatalog(nil)
+
+	compressedRoute, err := gzip.CompressBase64([]byte(`from("platform-http:test").log("hello")`))
+	require.NoError(t, err)
+
+	environment := Environment{
+		CamelCatalog: catalog,
+		Catalog:      traitCatalog,
+		Client:       client,
+		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      KnativeServiceTestName,
+				Namespace: KnativeServiceTestNamespace,
+			},
+			Status: v1.IntegrationStatus{
+				Phase: v1.IntegrationPhaseDeploying,
+			},
+			Spec: v1.IntegrationSpec{
+				Profile: v1.TraitProfileKnative,
+				Sources: []v1.SourceSpec{
+					{
+						DataSpec: v1.DataSpec{
+							Name:        "routes.js",
+							Content:     string(compressedRoute),
+							Compression: true,
+						},
+						Language: v1.LanguageJavaScript,
+					},
+				},
+			},
+		},
+		IntegrationKit: &v1.IntegrationKit{
+			Status: v1.IntegrationKitStatus{
+				Phase: v1.IntegrationKitPhaseReady,
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			Spec: v1.IntegrationPlatformSpec{
+				Cluster: v1.IntegrationPlatformClusterOpenShift,
+				Build: v1.IntegrationPlatformBuildSpec{
+					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
+					Registry:        v1.RegistrySpec{Address: "registry"},
+					RuntimeVersion:  catalog.Runtime.Version,
+				},
+			},
+			Status: v1.IntegrationPlatformStatus{
+				Phase: v1.IntegrationPlatformPhaseReady,
+			},
+		},
+		EnvVars:        make([]corev1.EnvVar, 0),
+		ExecutedTraits: make([]Trait, 0),
+		Resources:      kubernetes.NewCollection(),
+	}
+	environment.Platform.ResyncStatusFullConfig()
+
+	// don't care about conditions in this unit test
+	_, traits, err := traitCatalog.apply(&environment)
+
+	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
+	assert.NotEmpty(t, environment.ExecutedTraits)
+	assert.Equal(t, &traitv1.KnativeServiceTrait{
+		Trait: traitv1.Trait{
+			Enabled: ptr.To(true),
+		},
+	}, traits.KnativeService)
 }
