@@ -24,7 +24,7 @@ import (
 	"github.com/rs/xid"
 
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
@@ -57,6 +57,8 @@ type quarkusTrait struct {
 	traitv1.QuarkusTrait `property:",squash"`
 }
 type languageSettings struct {
+	// indicates whether the language is supported
+	deprecated bool
 	// indicates whether the native mode is supported
 	native bool
 	// indicates whether the sources are required at build time for native compilation
@@ -65,9 +67,9 @@ type languageSettings struct {
 
 var (
 	// settings for an unknown language.
-	defaultSettings = languageSettings{false, false}
+	defaultSettings = languageSettings{false, false, false}
 	// settings for languages supporting native mode for old catalogs.
-	nativeSupportSettings = languageSettings{true, false}
+	nativeSupportSettings = languageSettings{false, true, false}
 )
 
 // Retrieves the settings of the given language from the Camel catalog.
@@ -75,16 +77,16 @@ func getLanguageSettings(e *Environment, language v1.Language) languageSettings
 	if loader, ok := e.CamelCatalog.Loaders[string(language)]; ok {
 		native, nExists := loader.Metadata["native"]
 		if !nExists {
-			log.Debug("The metadata 'native' is absent from the Camel catalog, the legacy language settings are applied")
 			return getLegacyLanguageSettings(language)
 		}
 		sourcesRequiredAtBuildTime, sExists := loader.Metadata["sources-required-at-build-time"]
+		deprecated, dpExists := loader.Metadata["deprecated"]
 		return languageSettings{
 			native:                     native == boolean.TrueString,
 			sourcesRequiredAtBuildTime: sExists && sourcesRequiredAtBuildTime == boolean.TrueString,
+			deprecated:                 dpExists && deprecated == boolean.TrueString,
 		}
 	}
-	log.Debugf("No loader could be found for the language %q, the legacy language settings are applied", string(language))
 	return getLegacyLanguageSettings(language)
 }
 
@@ -140,11 +142,27 @@ func (t *quarkusTrait) Matches(trait Trait) bool {
 }
 
 func (t *quarkusTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
-	if e.CamelCatalog == nil {
-		return false, NewIntegrationConditionPlatformDisabledCatalogMissing(), nil
-	}
 	condition := t.adaptDeprecatedFields()
 
+	if t.languageSettingDeprecated(e) {
+		message := "The sources contains some language marked as deprecated. This Integration may not be supported in future release."
+		if condition == nil {
+			condition = NewIntegrationCondition(
+				"Quarkus", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, message)
+		} else {
+			condition.message += message
+		}
+	}
+
+	if t.containsMode(traitv1.NativeQuarkusMode) && e.IntegrationInPhase(v1.IntegrationPhaseBuildingKit) {
+		// Native compilation is only supported for a subset of languages,
+		// so let's check for compatibility, and fail-fast the Integration,
+		// to save compute resources and user time.
+		if err := t.validateNativeSupport(e); err != nil {
+			return false, nil, err
+		}
+	}
+
 	return e.IntegrationInPhase(v1.IntegrationPhaseBuildingKit) ||
 			e.IntegrationKitInPhase(v1.IntegrationKitPhaseBuildSubmitted) ||
 			e.IntegrationKitInPhase(v1.IntegrationKitPhaseReady) && e.IntegrationInRunningPhases(),
@@ -164,7 +182,31 @@ func (t *quarkusTrait) adaptDeprecatedFields() *TraitCondition {
 				t.Modes = append(t.Modes, traitv1.JvmQuarkusMode)
 			}
 		}
-		return NewIntegrationCondition("Quarkus", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, traitConfigurationReason, message)
+		return NewIntegrationCondition("Quarkus", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, message)
+	}
+
+	return nil
+}
+
+func (t *quarkusTrait) languageSettingDeprecated(e *Environment) bool {
+	if e.Integration == nil {
+		return false
+	}
+	for _, source := range e.Integration.AllSources() {
+		if language := source.InferLanguage(); getLanguageSettings(e, language).deprecated {
+			return true
+		}
+	}
+
+	return false
+}
+
+func (t *quarkusTrait) validateNativeSupport(e *Environment) error {
+	for _, source := range e.Integration.AllSources() {
+		if language := source.InferLanguage(); !getLanguageSettings(e, language).native {
+			return fmt.Errorf("invalid native support: Integration %s/%s contains a %s source that cannot be compiled to native executable",
+				e.Integration.Namespace, e.Integration.Name, language)
+		}
 	}
 
 	return nil
@@ -173,7 +215,6 @@ func (t *quarkusTrait) adaptDeprecatedFields() *TraitCondition {
 func (t *quarkusTrait) Apply(e *Environment) error {
 	if e.IntegrationInPhase(v1.IntegrationPhaseBuildingKit) {
 		t.applyWhileBuildingKit(e)
-
 		return nil
 	}
 
@@ -193,16 +234,6 @@ func (t *quarkusTrait) Apply(e *Environment) error {
 }
 
 func (t *quarkusTrait) applyWhileBuildingKit(e *Environment) {
-	if t.containsMode(traitv1.NativeQuarkusMode) {
-		// Native compilation is only supported for a subset of languages,
-		// so let's check for compatibility, and fail-fast the Integration,
-		// to save compute resources and user time.
-		if !t.validateNativeSupport(e) {
-			// Let the calling controller handle the Integration update
-			return
-		}
-	}
-
 	switch len(t.Modes) {
 	case 0:
 		// Default behavior
@@ -227,32 +258,14 @@ func (t *quarkusTrait) applyWhileBuildingKit(e *Environment) {
 	}
 }
 
-func (t *quarkusTrait) validateNativeSupport(e *Environment) bool {
-	for _, source := range e.Integration.AllSources() {
-		if language := source.InferLanguage(); !getLanguageSettings(e, language).native {
-			t.L.ForIntegration(e.Integration).Infof("Integration %s/%s contains a %s source that cannot be compiled to native executable", e.Integration.Namespace, e.Integration.Name, language)
-			e.Integration.Status.Phase = v1.IntegrationPhaseError
-			e.Integration.Status.SetCondition(
-				v1.IntegrationConditionKitAvailable,
-				corev1.ConditionFalse,
-				v1.IntegrationConditionUnsupportedLanguageReason,
-				fmt.Sprintf("native compilation for language %q is not supported", language))
-
-			return false
-		}
-	}
-
-	return true
-}
-
 func (t *quarkusTrait) newIntegrationKit(e *Environment, packageType quarkusPackageType) *v1.IntegrationKit {
 	integration := e.Integration
 	kit := v1.NewIntegrationKit(integration.GetIntegrationKitNamespace(e.Platform), fmt.Sprintf("kit-%s", xid.New()))
 
 	kit.Labels = map[string]string{
 		v1.IntegrationKitTypeLabel:            v1.IntegrationKitTypePlatform,
-		"camel.apache.org/runtime.version":    integration.Status.RuntimeVersion,
-		"camel.apache.org/runtime.provider":   string(integration.Status.RuntimeProvider),
+		kubernetes.CamelLabelRuntimeVersion:   integration.Status.RuntimeVersion,
+		kubernetes.CamelLabelRuntimeProvider:  string(integration.Status.RuntimeProvider),
 		v1.IntegrationKitLayoutLabel:          string(packageType),
 		v1.IntegrationKitPriorityLabel:        kitPriority[packageType],
 		kubernetes.CamelCreatorLabelKind:      v1.IntegrationKind,
@@ -315,8 +328,6 @@ func propagate(traitSource string, traits v1.Traits, kitTraits *v1.IntegrationKi
 		Builder: traits.Builder.DeepCopy(),
 		Camel:   traits.Camel.DeepCopy(),
 		Quarkus: traits.Quarkus.DeepCopy(),
-
-		Registry: traits.Registry.DeepCopy(),
 	}
 
 	if err := kitTraits.Merge(ikt); err != nil {
@@ -429,7 +440,7 @@ func (t *quarkusTrait) isIncrementalImageBuild(e *Environment) bool {
 	// We need to get this information from the builder trait
 	if trait := e.Catalog.GetTrait(builderTraitID); trait != nil {
 		builder, ok := trait.(*builderTrait)
-		return ok && pointer.BoolDeref(builder.IncrementalImageBuild, true)
+		return ok && ptr.Deref(builder.IncrementalImageBuild, true)
 	}
 
 	// Default always to true for performance reasons
@@ -452,7 +463,8 @@ func (t *quarkusTrait) applyWhenKitReady(e *Environment) error {
 
 func (t *quarkusTrait) isNativeIntegration(e *Environment) bool {
 	// The current IntegrationKit determines the Integration runtime type
-	return e.IntegrationKit.Labels[v1.IntegrationKitLayoutLabel] == v1.IntegrationKitLayoutNativeSources
+	return e.IntegrationKit != nil &&
+		e.IntegrationKit.Labels[v1.IntegrationKitLayoutLabel] == v1.IntegrationKitLayoutNativeSources
 }
 
 // Indicates whether the given source code is embedded into the final binary.
@@ -495,7 +507,7 @@ func sourcesRequiredAtBuildTime(e *Environment, source v1.SourceSpec) bool {
 // Propagates the user defined sources that are required at build time for native compilation.
 func propagateSourcesRequiredAtBuildTime(e *Environment) []v1.SourceSpec {
 	array := make([]v1.SourceSpec, 0)
-	for _, source := range e.Integration.UserDefinedSources() {
+	for _, source := range e.Integration.OriginalSources() {
 		if sourcesRequiredAtBuildTime(e, source) {
 			array = append(array, source)
 		}
