@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 
@@ -55,6 +56,21 @@ func TestConfigureQuarkusTraitBuildSubmitted(t *testing.T) {
 	assert.Len(t, packageTask.Steps, 4)
 }
 
+func TestConfigureQuarkusTraitNativeNotSupported(t *testing.T) {
+	quarkusTrait, environment := createNominalQuarkusTest()
+	// Set a source not supporting Quarkus native
+	environment.Integration.Spec.Sources[0].Language = v1.LanguageJavaScript
+	environment.Integration.Status.Phase = v1.IntegrationPhaseBuildingKit
+	quarkusTrait.Modes = []traitv1.QuarkusMode{traitv1.NativeQuarkusMode}
+
+	configured, condition, err := quarkusTrait.Configure(environment)
+
+	assert.False(t, configured)
+	require.Error(t, err)
+	assert.Equal(t, "invalid native support: Integration default/my-it contains a js source that cannot be compiled to native executable", err.Error())
+	assert.Nil(t, condition)
+}
+
 func TestApplyQuarkusTraitDefaultKitLayout(t *testing.T) {
 	quarkusTrait, environment := createNominalQuarkusTest()
 	environment.Integration.Status.Phase = v1.IntegrationPhaseBuildingKit
@@ -96,6 +112,10 @@ func createNominalQuarkusTest() (*quarkusTrait, *Environment) {
 		Catalog:      NewCatalog(client),
 		CamelCatalog: &camel.RuntimeCatalog{},
 		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "default",
+				Name:      "my-it",
+			},
 			Spec: v1.IntegrationSpec{
 				Sources: []v1.SourceSpec{
 					{
@@ -236,3 +256,59 @@ func TestQuarkusMatches(t *testing.T) {
 	qt2.NativeBaseImage = "docker.io/my-new-native-base"
 	assert.False(t, qt.Matches(&qt2))
 }
+
+func TestConfigureQuarkusTraitDeprecatedPackageType(t *testing.T) {
+	quarkusTrait, environment := createNominalQuarkusTest()
+	quarkusTrait.PackageTypes = []traitv1.QuarkusPackageType{
+		traitv1.FastJarPackageType,
+	}
+	environment.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseBuildSubmitted
+	configured, condition, err := quarkusTrait.Configure(environment)
+
+	assert.True(t, configured)
+	require.NoError(t, err)
+	assert.NotNil(t, condition)
+	assert.Equal(t, "The package-type parameter is deprecated and may be removed in future releases. Make sure to use mode parameter instead.", condition.message)
+	assert.Equal(t, traitv1.JvmQuarkusMode, quarkusTrait.QuarkusTrait.Modes[0])
+}
+
+func TestConfigureQuarkusTraitSupportedLanguages(t *testing.T) {
+	quarkusTrait, environment := createNominalQuarkusTest()
+	environment.CamelCatalog.Loaders = map[string]v1.CamelLoader{
+		"supportedLanguage": {
+			Metadata: map[string]string{
+				"deprecated":                     "false",
+				"native":                         "true",
+				"sources-required-at-build-time": "false",
+			},
+		},
+	}
+	environment.Integration.Spec.Sources[0].Language = v1.Language("supportedLanguage")
+	environment.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseBuildSubmitted
+	configured, condition, err := quarkusTrait.Configure(environment)
+
+	assert.True(t, configured)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
+}
+
+func TestConfigureQuarkusTraitDeprecatedLanguages(t *testing.T) {
+	quarkusTrait, environment := createNominalQuarkusTest()
+	environment.CamelCatalog.Loaders = map[string]v1.CamelLoader{
+		"deprecatedLanguage": {
+			Metadata: map[string]string{
+				"deprecated":                     "true",
+				"native":                         "false",
+				"sources-required-at-build-time": "false",
+			},
+		},
+	}
+	environment.Integration.Spec.Sources[0].Language = v1.Language("deprecatedLanguage")
+	environment.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseBuildSubmitted
+	configured, condition, err := quarkusTrait.Configure(environment)
+
+	assert.True(t, configured)
+	require.NoError(t, err)
+	assert.NotNil(t, condition)
+	assert.Equal(t, "The sources contains some language marked as deprecated. This Integration may not be supported in future release.", condition.message)
+}
