@@ -39,6 +39,13 @@ $(go env GOPATH)/bin/client-gen \
 	--output-base=. \
 	--output-package=github.com/apache/camel-k/v2/pkg/client/camel/clientset
 
+$(go env GOPATH)/bin/client-gen \
+  --input strimzi/v1beta2 \
+  --go-header-file=../../../script/headers/default.txt \
+  --input-base=github.com/apache/camel-k/v2/pkg/apis/duck \
+  --output-base=. \
+  --output-package=github.com/apache/camel-k/v2/pkg/client/duck/strimzi/clientset
+
 $(go env GOPATH)/bin/lister-gen \
 	--input-dirs=github.com/apache/camel-k/v2/pkg/apis/camel/v1,github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1 \
 	--go-header-file=../../../script/headers/default.txt \
@@ -53,10 +60,10 @@ $(go env GOPATH)/bin/informer-gen \
 	--output-base=. \
 	--output-package=github.com/apache/camel-k/v2/pkg/client/camel/informers
 
-
 # hack to fix non go-module compliance
 rm -rf ./clientset
 rm -rf ./informers
 rm -rf ./listers
 cp -R ./github.com/apache/camel-k/v2/pkg/client/camel/* .
+cp -R ./github.com/apache/camel-k/v2/pkg/client/* ..
 rm -rf ./github.com
